/*-- pre-processor statements for conditional code --*/

/* %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
+

    System: UCL Cryosat IO Library

    Sub-system: Examples

    Description: Example code for reading of Cryosat Level 1b products.


    ----------------------------------------------
    Documentation cross reference:
    Cryosat IO Library manual

    ----------------------------------------------
    This file lives in ---
    ./src

    Coding by:
    David J Brockley
    http://cryosat.mssl.ucl.ac.uk/public

    ----------------------------------------------
    Filename              :     $RCSfile: cs_l1b_io_example.c,v $
    CVS Version Number    :     $Revision: 1.3 $
    Last Update           :     $Date: 2014/12/01 11:30:14 $
    What String           :     @(#)$Id: cs_l1b_io_example.c,v 1.3 2014/12/01 11:30:14 djb Exp $
    Log                   :
                                $Log: cs_l1b_io_example.c,v $
                                Revision 1.3  2014/12/01 11:30:14  djb
                                Pre-testing for release v2.1

                                Revision 1.2  2010/08/27 09:22:58  djb
                                Prototype changes to fix on 64 bit machines and to correct the size of the quality flag in L2.

                                Revision 1.1  2010/07/16 14:37:55  djb
                                Port in CryoSat tools from internal branch.

                                Revision 1.3  2005/10/13 14:04:46  djb
                                More updates for 0.3 release

                                Revision 1.2  2005/10/12 13:40:27  djb
                                Updates for 0.3 release.

                                Revision 1.1  2005/10/04 08:53:06  djb
                                Added more files and documentation.



    ----------------------------------------------
    Routines:
    main

    -----------------------------------------------------------
    This file contains the Unpublished Intellectual Property of
    University College London and All Rights Are Reserved.
        Copyright (c) University College London, 2005
    -----------------------------------------------------------
-
*/

#pragma ident "@(#)$Id: cs_l1b_io_example.c,v 1.3 2014/12/01 11:30:14 djb Exp $ MSSL"

/*-- pre-processor statements --*/

/*-- standard C headers --*/
#include <stdio.h>
#include <stdlib.h>
#include <string.h>
#include <stdint.h>
#include <inttypes.h>

/*-- programmer created headers --*/
#include "ptCSGetFileHandle.h"
#include "vCSFreeFileHandle.h"
#include "ptCSGetL1b.h"
#include "jCSNumRecordsInDataset.h"
#include "jCSGetDSFileOffsetFromHeader.h"
#include "BitmaskUtilities.h"
#include "jIOFunctions.h"
#include "CS_Defines.h"

/*-- constant and macro headers --*/

/*-- type definitions --*/

/*-- global and external variable declarations --*/

/*-- module private (static) variable declarations --*/

/*-- functions --*/

int
main( int   argc,
      char* argv[] )
{
    L1B_LRM*        pt_L1b_LRM   = NULL;
    L1B_SAR*        pt_L1b_SAR   = NULL;
    L1B_SARIN*      pt_L1b_SARIN = NULL;

    t_cs_filehandle t_handle     = NULL;

    long int        j_records    = 0;
    long int        j_result     = 0;
    long int        i            = 0;
    long int        j_actual     = 0;

    CS_DS_NAME      t_ds_type = CS_DS_NAME_NONE;
    BASELINE        t_baseline = BASELINE_A;

    gj_verbose = 1;

    if( argc != 2 && argc != 3 )
    {
        printf( "usage: %s filename [baseline ID]\n", argv[ 0 ] );
        printf( "  baseline ID: 1=A 2=B 3=BC 4=C\n" );
        return EXIT_FAILURE;
    }

    if( argc == 3 )
    {
        switch( atol( argv[2] ) )
        {
            case 1:
                t_baseline = BASELINE_A;
                printf( "Expecting Baseline A data\n" );
                break;
            case 2:
                t_baseline = BASELINE_B;
                printf( "Expecting Baseline B data\n" );
                break;
            case 3:
                t_baseline = BASELINE_BC;
                printf( "Expecting Baseline BC data\n" );
                break;
            case 4:
                t_baseline = BASELINE_C;
                printf( "Expecting Baseline C data\n" );
                break;
            default:
                printf( "Unknown baseline ID\n" );
                return EXIT_FAILURE;
        }
    }

    iTestEndian();

    t_handle = ptCSGetFileHandle(argv[ 1 ], t_baseline);

    if( t_handle != NULL )
    {
        /*
         * This is one way to determine what kind of file this is, by
         * looking at the header for each of the DS_NAMEs that we can
         * read in turn.
         */

        j_result = jCSGetDSFileOffsetFromHeader(NULL, NULL,
                                                 argv[ 1 ], CS_L1B_DS_NAME_LRM, &j_actual );

        if( j_result != EXIT_SUCCESS )
        {
            if( strstr( argv[1], "INT_LRM_1B" ) )
            {
                j_result = EXIT_SUCCESS;
            }
        }

        if( j_result == EXIT_SUCCESS )
        {
            printf( "Dataset of type L1b LRM detected in file.\n" );
            t_ds_type = CS_L1B_DS_NAME_LRM;
        }

        if( t_ds_type == CS_DS_NAME_NONE )
        {
            j_result = jCSGetDSFileOffsetFromHeader(NULL, NULL,
                                                     argv[ 1 ], CS_L1B_DS_NAME_SAR, &j_actual );

             if( j_result != EXIT_SUCCESS )
             {
                 if( strstr( argv[1], "INT_SAR_1B" ) || strstr( argv[1], "INT_SAR__A" ) )
                 {
                     j_result = EXIT_SUCCESS;
                 }
             }
            if( j_result == EXIT_SUCCESS )
            {
                printf( "Dataset of type L1b SAR detected in file.\n" );
                t_ds_type = CS_L1B_DS_NAME_SAR;
            }
        }

        if( t_ds_type == CS_DS_NAME_NONE )
        {
            j_result = jCSGetDSFileOffsetFromHeader(NULL, NULL,
                                                     argv[ 1 ], CS_L1B_DS_NAME_SARIN, &j_actual );

             if( j_result != EXIT_SUCCESS )
             {
                 if( strstr( argv[1], "INT_SIN_1B" ) )
                 {
                     j_result = EXIT_SUCCESS;
                 }
             }

            if( j_result == EXIT_SUCCESS )
            {
                printf( "Dataset of type L1b SARIN detected in file.\n" );
                t_ds_type = CS_L1B_DS_NAME_SARIN;
            }
        }

        if( t_ds_type == CS_DS_NAME_NONE )
        {
            printf( "Unable to determine type of file.\n" );
            return EXIT_FAILURE;
        }

        j_records = jCSNumRecordsInDataset( t_handle, 0 );

        if( j_records == -1 )
        {
            printf( "Unable to get number of records in file.\n" );
            return EXIT_FAILURE;
        }

        printf( "There are %ld records in the file %s\n",
                j_records, argv[ 1 ] );

        switch( t_ds_type )
        {
            case CS_L1B_DS_NAME_LRM:
            {
                pt_L1b_LRM = ptCSGetL1bLRM( t_handle,
                                            0,
                                            j_records,
                                            0,
                                            NULL );

                if( pt_L1b_LRM != NULL )
                {
                    printf( "L1b day [0][0]= %"PRId32"\n",
                            pt_L1b_LRM[ 0 ].at_Time_Orbit[ 0 ].j_Day );
                    printf( "L1b day [0][1]= %"PRId32"\n",
                            pt_L1b_LRM[ 0 ].at_Time_Orbit[ 1 ].j_Day );
                    printf( "L1b day [1][0]= %"PRId32"\n",
                            pt_L1b_LRM[ 1 ].at_Time_Orbit[ 0 ].j_Day );

                    /*
                    * Demonstrate how to check bits in flag words by
                    * counting the number of blank blocks at the end of
                    * the file.
                    */
                    for( i = 19; i > 0; i-- )
                    {
                        j_result = iCheckBitLong( &pt_L1b_LRM[ j_records - 1 ].
                            at_Time_Orbit[ i ].uj_MCD,
                            MCD_BLOCK_BLANK );

                        /* Stop as soon as a non-blank block is found. */
                        if( !j_result )
                        {
                            printf( "There are %ld blank blocks at the end of the file.\n",
                                20 - i - 1 );
                            break;
                        }
                    }

                    printf( "\n\n ** DUMP[0] ** \n\n" );
                    vDump_L1B_LRM( &pt_L1b_LRM[ 0 ], NULL );
                    printf( "\n\n ** DUMP[1] ** \n\n" );
                    vDump_L1B_LRM( &pt_L1b_LRM[ 1 ], NULL );
                }
                else
                {
                    printf( "Unable to read from file.\n" );
                    return EXIT_FAILURE;
                }

                free( pt_L1b_LRM );
            } break;

            case CS_L1B_DS_NAME_SAR:
            {
                pt_L1b_SAR = ptCSGetL1bSAR( t_handle,
                                            0,
                                            j_records,
                                            0,
                                            NULL );

                if( pt_L1b_SAR != NULL )
                {
                    printf( "L1b day [0][0]= %"PRId32"\n",
                        pt_L1b_SAR[ 0 ].at_Time_Orbit[ 0 ].j_Day );
                    printf( "L1b day [0][1]= %"PRId32"\n",
                        pt_L1b_SAR[ 0 ].at_Time_Orbit[ 1 ].j_Day );
                    printf( "L1b day [1][0]= %"PRId32"\n",
                        pt_L1b_SAR[ 1 ].at_Time_Orbit[ 0 ].j_Day );
                    /*
                    * Demonstrate how to check bits in flag words by
                    * counting the number of blank blocks at the end of
                    * the file.
                    */
                    for( i = 19; i > 0; i-- )
                    {
                        j_result = iCheckBitLong( &pt_L1b_SAR[ j_records - 1 ].
                            at_Time_Orbit[ i ].uj_MCD,
                            MCD_BLOCK_BLANK );

                        /* Stop as soon as a non-blank block is found. */
                        if( !j_result )
                        {
                            printf( "There are %ld blank blocks at the end of the file.\n",
                                20 - i - 1 );
                            break;
                        }
                    }

                    printf( "\n\n ** DUMP[0] ** \n\n" );
                    vDump_L1B_SAR( &pt_L1b_SAR[ 0 ], NULL );
                    printf( "\n\n ** DUMP[1] ** \n\n" );
                    vDump_L1B_SAR( &pt_L1b_SAR[ 1 ], NULL );
                }
                else
                {
                    printf( "Unable to read from file.\n" );
                    return EXIT_FAILURE;
                }

                free( pt_L1b_SAR );
            } break;

            case CS_L1B_DS_NAME_SARIN:
            {
                pt_L1b_SARIN = ptCSGetL1bSARIN( t_handle,
                                                0,
                                                j_records,
                                                0,
                                                NULL );

                if( pt_L1b_SARIN != NULL )
                {
                    printf( "L1b day [0][0]= %"PRId32"\n",
                         pt_L1b_SARIN[ 0 ].at_Time_Orbit[ 0 ].j_Day );
                     printf( "L1b day [0][1]= %"PRId32"\n",
                         pt_L1b_SARIN[ 0 ].at_Time_Orbit[ 1 ].j_Day );
                     printf( "L1b day [1][0]= %"PRId32"\n",
                         pt_L1b_SARIN[ 1 ].at_Time_Orbit[ 0 ].j_Day );
                    /*
                     * Demonstrate how to check bits in flag words by
                     * counting the number of blank blocks at the end of
                     * the file.
                     */
                    for( i = 19; i > 0; i-- )
                    {
                        j_result = iCheckBitLong( &pt_L1b_SARIN[ j_records - 1 ].
                                                      at_Time_Orbit[ i ].uj_MCD,
                                                  MCD_BLOCK_BLANK );

                        /* Stop as soon as a non-blank block is found. */
                        if( !j_result )
                        {
                            printf( "There are %ld blank blocks at the end of the file.\n",
                                    20 - i - 1 );
                            break;
                        }
                    }

                    if( i == 19 )
                    {
                        printf( "There are no blank blocks at the end of this file.\n" );
                    }

                    if( i == 0 )
                    {
                        printf( "This file has an entirely blank record at the end.\n" );
                    }

                    printf( "\n\n ** DUMP[0] ** \n\n" );
                    vDump_L1B_SARIN( &pt_L1b_SARIN[ 0 ], NULL );
                    printf( "\n\n ** DUMP[1] ** \n\n" );
                    vDump_L1B_SARIN( &pt_L1b_SARIN[ 1 ], NULL );
                }
                else
                {
                    printf( "Unable to read from file.\n" );
                    return EXIT_FAILURE;
                }

                free( pt_L1b_SARIN );
            } break;

            default:
                printf( "Unable to find a dataset of a type that the library can read. No header and odd filename?\n" );
        } /* switch */

        vCSFreeFileHandle( t_handle );
    }
    else
    {
        printf( "Unable to open file.\n" );
        return EXIT_FAILURE;
    }

    return EXIT_SUCCESS;
} /* main */
