/*-- pre-processor statements for conditional code --*/

/* %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
+

    System: UCL Cryosat IO Library

    Sub-system: Examples

    Description: Example code for reading of Cryosat Level 2 Intermediate products.


    ----------------------------------------------
    Documentation cross reference:
    Cryosat IO Library manual

    ----------------------------------------------
    This file lives in ---
    ./src

    Coding by:
    David J Brockley
    http://cryosat.mssl.ucl.ac.uk/public

    ----------------------------------------------
    Filename              :     $RCSfile: cs_l2i_io_example.c,v $
    CVS Version Number    :     $Revision: 1.3 $
    Last Update           :     $Date: 2014/12/01 11:30:14 $
    What String           :     @(#)$Id: cs_l2i_io_example.c,v 1.3 2014/12/01 11:30:14 djb Exp $
    Log                   :
                                $Log: cs_l2i_io_example.c,v $
                                Revision 1.3  2014/12/01 11:30:14  djb
                                Pre-testing for release v2.1

                                Revision 1.2  2010/08/27 09:22:59  djb
                                Prototype changes to fix on 64 bit machines and to correct the size of the quality flag in L2.

                                Revision 1.1  2010/07/16 14:37:55  djb
                                Port in CryoSat tools from internal branch.

                                Revision 1.2  2005/09/26 09:50:21  djb
                                Changes to documentation.

                                Revision 1.1.1.1  2005/09/23 13:51:56  djb
                                Initial import of sources to CVS.


    ----------------------------------------------
    Routines:
    main

    -----------------------------------------------------------
    This file contains the Unpublished Intellectual Property of
    University College London and All Rights Are Reserved.
        Copyright (c) University College London, 2005
    -----------------------------------------------------------
-
*/

#pragma ident "@(#)$Id: cs_l2i_io_example.c,v 1.3 2014/12/01 11:30:14 djb Exp $ MSSL"

/*-- pre-processor statements --*/

/*-- standard C headers --*/
#include <stdio.h>
#include <stdlib.h>
#include <stdint.h>
#include <inttypes.h>

/*-- programmer created headers --*/
#include "ptCSGetFileHandle.h"
#include "vCSFreeFileHandle.h"
#include "ptCSGetL2I.h"
#include "jCSNumRecordsInDataset.h"
#include "jIOFunctions.h"
#include "CS_Defines.h"

/*-- constant and macro headers --*/

/*-- type definitions --*/

/*-- global and external variable declarations --*/

/*-- module private (static) variable declarations --*/

/*-- functions --*/

int
main( int   argc,
      char* argv[] )
{
    L2IData*        pt_L2     = NULL;
    t_cs_filehandle t_handle  = NULL;
    BASELINE        t_baseline = BASELINE_A;

    long int        j_records = 0;

    gj_verbose = 1;

    if( argc != 2 && argc != 3 )
    {
        printf( "usage: %s filename [baseline ID]\n", argv[ 0 ] );
        printf( "  baseline ID: 1=A 2=B 3=BC 4=C\n" );
        return EXIT_FAILURE;
    }

    if( argc == 3 )
    {
        switch( atol( argv[2] ) )
        {
            case 1:
                t_baseline = BASELINE_A;
                printf( "Expecting Baseline A data\n" );
                break;
            case 2:
                t_baseline = BASELINE_B;
                printf( "Expecting Baseline B data\n" );
                break;
            case 3:
                t_baseline = BASELINE_BC;
                printf( "Expecting Baseline BC data\n" );
                break;
            case 4:
                t_baseline = BASELINE_C;
                printf( "Expecting Baseline C data\n" );
                break;
            default:
                printf( "Unknown baseline ID\n" );
                return EXIT_FAILURE;
        }
    }

    iTestEndian();

    t_handle = ptCSGetFileHandle(argv[ 1 ], t_baseline );

    if( t_handle != NULL )
    {
        j_records = jCSNumRecordsInDataset( t_handle, 0 );

        if( j_records == -1 )
        {
            printf( "Unable to get number of records in file.\n" );
            return EXIT_FAILURE;
        }

        printf( "There are %ld records in the file %s\n",
                j_records, argv[ 1 ] );

        pt_L2 = ptCSGetL2I( t_handle,
                            0,
                            j_records,
                            0,
                            NULL );

        if( pt_L2 != NULL )
        {
            printf( "L2 day [0] = %"PRId32"\n", pt_L2[ 0 ].j_Day );
            printf( "L2 day [1] = %"PRId32"\n", pt_L2[ 1 ].j_Day );

            printf( "\n\n ** DUMP[0] ** \n\n" );
            vDump_L2IData( &pt_L2[ 0 ], NULL );
            printf( "\n\n ** DUMP[1] ** \n\n" );
            vDump_L2IData( &pt_L2[ 1 ], NULL );
        }
        else
        {
            printf( "Unable to read from file.\n" );
            return EXIT_FAILURE;
        }

        free( pt_L2 );

        vCSFreeFileHandle( t_handle );
    }
    else
    {
        printf( "Unable to open file.\n" );
        return EXIT_FAILURE;
    }

    return EXIT_SUCCESS;
} /* main */
