/*-- pre-processor statements for conditional code --*/

/* %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
+

    System: UCL Cryosat IO Library

    Sub-system: Examples

    Description: Example code testing, clearing and setting bits


    ----------------------------------------------
    Documentation cross reference:
    Cryosat IO Library manual

    ----------------------------------------------
    This file lives in ---
    ./src

    Coding by:
    David J Brockley
    http://cryosat.mssl.ucl.ac.uk/public

    ----------------------------------------------
    Filename              :     $RCSfile: example_bit_manipulation.c,v $
    CVS Version Number    :     $Revision: 1.2 $
    Last Update           :     $Date: 2014/12/01 11:30:14 $
    What String           :     @(#)$Id: example_bit_manipulation.c,v 1.2 2014/12/01 11:30:14 djb Exp $
    Log                   :
                                $Log: example_bit_manipulation.c,v $
                                Revision 1.2  2014/12/01 11:30:14  djb
                                Pre-testing for release v2.1

                                Revision 1.1  2010/07/16 14:37:55  djb
                                Port in CryoSat tools from internal branch.




    ----------------------------------------------
    Routines:
    main

    -----------------------------------------------------------
    This file contains the Unpublished Intellectual Property of
    University College London and All Rights Are Reserved.
        Copyright (c) University College London, 2005
    -----------------------------------------------------------
-
*/

#pragma ident "@(#)$Id: example_bit_manipulation.c,v 1.2 2014/12/01 11:30:14 djb Exp $ MSSL"

/*-- pre-processor statements --*/

/*-- standard C headers --*/
#include <stdio.h>
#include <stdlib.h>

/*-- programmer created headers --*/
#include "ptCSGetFileHandle.h"
#include "vCSFreeFileHandle.h"
#include "ptCSGetL1b.h"
#include "jCSNumRecordsInDataset.h"
#include "jCSGetDSFileOffsetFromHeader.h"
#include "BitmaskUtilities.h"
#include "jIOFunctions.h"

/*-- constant and macro headers --*/

/*-- type definitions --*/

/*-- global and external variable declarations --*/

/*-- module private (static) variable declarations --*/

/*-- functions --*/

int
main( int   argc,
      char* argv[] )
{
    L1B_LRM*        pt_L1b_LRM = NULL;

    t_cs_filehandle t_handle   = NULL;

    long int        j_records  = 0;
    long int        j_result   = 0;
    long int        i          = 0;
    long int        j_actual   = 0;

    CS_DS_NAME      t_ds_type  = CS_DS_NAME_NONE;

    if( argc != 2 )
    {
        printf( "usage: %s filename\n", argv[ 0 ] );

        return EXIT_FAILURE;
    }

    iTestEndian();

    t_handle = ptCSGetFileHandle(argv[ 1 ], BASELINE_A );

    if( t_handle != NULL )
    {
        /*
         * This is one way to determine what kind of file this is, by
         * looking at the header for each of the DS_NAMEs that we can
         * read in turn.
         */

        j_result = jCSGetDSFileOffsetFromHeader(NULL, NULL,
                                                 argv[ 1 ], CS_L1B_DS_NAME_LRM, &j_actual );

        if( j_result == EXIT_SUCCESS )
        {
            printf( "Dataset of type L1b LRM detected in file.\n" );
            t_ds_type = CS_L1B_DS_NAME_LRM;

            j_records = jCSNumRecordsInDataset( t_handle, 0 );

            if( j_records == -1 )
            {
                printf( "Unable to get number of records in file.\n" );
                return EXIT_FAILURE;
            }

            /* Read in one record for test purposes */
            pt_L1b_LRM = ptCSGetL1bLRM( t_handle,
                                        0,
                                        j_records,
                                        1,
                                        NULL );

            if( pt_L1b_LRM != NULL )
            {
                /* Now to look at the bits */
                j_result = iCheckBitShort( &pt_L1b_LRM->
                                               t_Average_PL.ui_flags,
                                           WFM_LRM_ERROR );

                if( j_result )
                {
                    /* The bit was set */
                    printf( "Averaged waveform error\n" );
                }
                else
                {
                    /* The bit was clear */
                    printf( "Averaged waveform ok\n" );
                }

                /*
                 * Just to show how, this is how to set the bit to what
                 * we have already determined its value to be.
                 */
                if( j_result )
                {
                    vSetBitShort( &pt_L1b_LRM->
                                      t_Average_PL.ui_flags,
                                  WFM_LRM_ERROR );
                }
                else
                {
                    vClearBitShort( &pt_L1b_LRM->
                                        t_Average_PL.ui_flags,
                                    WFM_LRM_ERROR );
                }
            }
        }
    }
} /* main */
