#include "L2Structure.h"
#include "L1bStructure.h"

/**
 * @file   L2Structure.c
 *
 * @brief  Convenience functions for the L2 structure.
 *
 *
 */

static void vDump_L2FinalC( L2FinalC* pt, FILE* pf );
static void vDump_L2FinalM( L2FinalM* pt, FILE* pf );

/** 
 Create an ASCII dump of an L2 product to a file.

 @param pt Pointer to the product to dump.
 @param pf Pointer to the file to dump to.
*/
void vDump_L2Data( L2Data* pt, FILE* pf )
{
    int i;
    if( pf == NULL ) pf = stdout;
    fprintf( pf, "%s = %"PRId32"\n", "j_Day", pt->j_Day );
    fprintf( pf, "%s = %"PRIu32"\n", "uj_Sec", pt->uj_Sec );
    fprintf( pf, "%s = %"PRIu32"\n", "uj_Micsec", pt->uj_Micsec );
    fprintf( pf, "%s = %"PRIu64"\n", "uk_Siral_mode", pt->uk_Siral_mode );
    fprintf( pf, "%s = %"PRId32"\n", "j_Lat_1Hz", pt->j_Lat_1Hz );
    fprintf( pf, "%s = %"PRId32"\n", "j_Lon_1Hz", pt->j_Lon_1Hz );
    fprintf( pf, "%s = %"PRId32"\n", "j_Alt_1Hz", pt->j_Alt_1Hz );
    fprintf( pf, "%s = %"PRId16"\n", "i_Mispointing", pt->i_Mispointing );
    fprintf( pf, "%s = %"PRId32"\n", "j_Roll_angle", pt->j_Roll_angle );
    fprintf( pf, "%s = %"PRId32"\n", "j_Pitch_angle", pt->j_Pitch_angle );
    fprintf( pf, "%s = %"PRId32"\n", "j_Yaw_angle", pt->j_Yaw_angle );
    fprintf( pf, "%s = %"PRId16"\n", "i_N_Valid", pt->i_N_Valid );

    vDump_L2FinalC( &pt->t_Corr, pf );
    for( i = 0; i < J_NUM_HRB; i++ )
    {
        vDump_L2FinalM( &pt->at_Meas[i], pf );
    }
}

/** 
 Create an ASCII dump of an L2 corrections struture to a file.

 @param pt Pointer to the structure to dump.
 @param pf Pointer to the file to dump to.
*/
void vDump_L2FinalC( L2FinalC* pt, FILE* pf )
{
    if( pf == NULL ) pf = stdout;
    fprintf( pf, "%s = %"PRId16"\n", "i_Dry_C", pt->i_Dry_C );
    fprintf( pf, "%s = %"PRId16"\n", "i_Wet_C", pt->i_Wet_C );
    fprintf( pf, "%s = %"PRId16"\n", "i_IB_C", pt->i_IB_C );
    fprintf( pf, "%s = %"PRId16"\n", "i_DAC_C", pt->i_DAC_C );
    fprintf( pf, "%s = %"PRId16"\n", "i_Iono_C", pt->i_Iono_C );
    fprintf( pf, "%s = %"PRId16"\n", "i_SSB", pt->i_SSB );
    fprintf( pf, "%s = %"PRId16"\n", "i_H_OT", pt->i_H_OT );
    fprintf( pf, "%s = %"PRId16"\n", "i_H_LPEOT", pt->i_H_LPEOT );
    fprintf( pf, "%s = %"PRId16"\n", "i_H_OLT", pt->i_H_OLT );
    fprintf( pf, "%s = %"PRId16"\n", "i_H_SET", pt->i_H_SET );
    fprintf( pf, "%s = %"PRId16"\n", "i_H_GPT", pt->i_H_GPT );
    fprintf( pf, "%s = %"PRId16"\n", "i_Spare1", pt->i_Spare1 );
    fprintf( pf, "%s = %"PRIu64"\n", "uk_Surf_type", pt->uk_Surf_type );
    fprintf( pf, "%s = %"PRId32"\n", "j_MSS_Geoid", pt->j_MSS_Geoid );
    fprintf( pf, "%s = %"PRId32"\n", "j_ODLE", pt->j_ODLE );
    fprintf( pf, "%s = %"PRId16"\n", "i_Ice_conc", pt->i_Ice_conc );
    fprintf( pf, "%s = %"PRId16"\n", "i_Snow_depth", pt->i_Snow_depth );
    fprintf( pf, "%s = %"PRId16"\n", "i_Snow_density", pt->i_Snow_density );
    fprintf( pf, "%s = %"PRIu32"\n", "uj_C_status", pt->uj_C_status );
    fprintf( pf, "%s = %"PRId16"\n", "i_SWH", pt->i_SWH );
    fprintf( pf, "%s = %"PRIu16"\n", "ui_Wind_speed", pt->ui_Wind_speed );
}

/** 
 Create an ASCII dump of an L2 measurements structure to a file.

 @param pt Pointer to the structure to dump.
 @param pf Pointer to the file to dump to.
*/
void vDump_L2FinalM( L2FinalM* pt, FILE* pf )
{
    if( pf == NULL ) pf = stdout;
    fprintf( pf, "%s = %"PRId32"\n", "j_D_time_mics", pt->j_D_time_mics );
    fprintf( pf, "%s = %"PRId32"\n", "j_Lat", pt->j_Lat );
    fprintf( pf, "%s = %"PRId32"\n", "j_Lon", pt->j_Lon );
    fprintf( pf, "%s = %"PRId32"\n", "j_Height", pt->j_Height );
    fprintf( pf, "%s = %"PRId32"\n", "j_Height_2", pt->j_Height_2 );
    fprintf( pf, "%s = %"PRId32"\n", "j_Height_3", pt->j_Height_3 );
    fprintf( pf, "%s = %"PRId16"\n", "i_SSHA_interp", pt->i_SSHA_interp );
    fprintf( pf, "%s = %"PRId16"\n", "i_SSHA_num", pt->i_SSHA_num );
    fprintf( pf, "%s = %"PRId16"\n", "i_SSHA_qual", pt->i_SSHA_qual );
    fprintf( pf, "%s = %"PRId16"\n", "i_Sig0", pt->i_Sig0 );
    fprintf( pf, "%s = %"PRId16"\n", "i_Sig0_2", pt->i_Sig0_2 );
    fprintf( pf, "%s = %"PRId16"\n", "i_Sig0_3", pt->i_Sig0_3 );
    fprintf( pf, "%s = %"PRId16"\n", "i_Peakiness", pt->i_Peakiness );
    fprintf( pf, "%s = %"PRId16"\n", "i_Freeboard", pt->i_Freeboard );
    fprintf( pf, "%s = %"PRId16"\n", "i_N_avg", pt->i_N_avg );
    fprintf( pf, "%s = %"PRIu32"\n", "uj_Quality_F", pt->uj_Quality_F );
    fprintf( pf, "%s = %"PRIu32"\n", "uj_C_applied", pt->uj_C_applied );
    fprintf( pf, "%s = %"PRId32"\n", "j_Quality_1", pt->j_Quality_1 );
    fprintf( pf, "%s = %"PRId32"\n", "j_Quality_2", pt->j_Quality_2 );
    fprintf( pf, "%s = %"PRId32"\n", "j_Quality_3", pt->j_Quality_3 );
}