#ifndef SHAREDFLAGS_H_74A678A2
#define SHAREDFLAGS_H_74A678A2

/**
 * @file   SharedFlags.h
 *
 * @brief  Enums for bitfield definitions and flags shared between L1b, L2, and L2i.
 *
 * This file contains convenience enums that describe bitfield settings for flags
 * that are used unchanged in more than one of the products.
 */

/** Level 1b MCD bit definitions for TimeAndOrbitGroup#uj_MCD, L2IData#uj_L2_MCD */
typedef enum _t_MCDFlagBit
{
    MCD_BLOCK_DEGRADED                = 31, /**< Block degraded */
    MCD_BLOCK_BLANK                   = 30, /**< Blank inserted for
                                             *   padding
                                             */
    MCD_DATATION_DEGRADED             = 29, /**< Datation blank or not set */
    MCD_ORBIT_PROP_ERROR              = 28, /**< Error returned by CFI
                                             *   or other check
                                             */
    MCD_ORBIT_FILE_CHANGE             = 27, /**< Orbit file changed since
                                             *   previous record
                                             */
    MCD_ORBIT_DISCONTINUITY           = 26, /**< Discontinuity (gap) */
    MCD_ECHO_SATURATION               = 25, /**< Saturated echo */
    MCD_ECHO_ERROR                    = 24, /**< Another kind of echo error */
    MCD_CH1_ERROR                     = 23, /**< Recieve channel degraded or
                                             *   missing
                                             */
    MCD_CH2_ERROR                     = 22, /**< Recieve channel degraded or
                                             *   missing
                                             */
    MCD_WINDOW_DELAY_INCONSISTANT     = 21, /**< Window delay
                                             *   inconsistancy.
                                             */
    MCD_AGC_INCONSISTANT              = 20, /**< AGC
                                             *   inconsistancy.
                                             */
    MCD_CAL_1_CORR_MISSING            = 19, /**< CAL 1 correction
                                             *   missing.
                                             *   Correction was
                                             *   not applied.
                                             */
    MCD_CAL_1_IPF_DB_USED             = 18, /**< CAL 1 correction
                                             * applied was from
                                             * the IPF DB.
                                             */
    MCD_DORIS_USO_CORR_MISSING        = 17, /**< DORIS USO
                                             *   correction not
                                             *   available.
                                             */
    MCD_C_CAL_1_IPF_DB_USED           = 16, /**< Complex CAL1 correction
                                             *   applied was from the
                                             *   IPF DB.
                                             */
    MCD_TRK_ECHO_ERROR                = 15, /**< Degraded
                                             *   tracking echo.
                                             */
    MCD_ECHO_RX1_ERROR                = 14, /**< Bad raw echo on
                                             *   recieve chain 1.
                                             */
    MCD_ECHO_RX2_ERROR                = 13, /**< Bad raw echo on
                                             *   recieve chain 2.
                                             */
    MCD_NPM_INCONSISTANT              = 12, /**< NPM inconsistancy.
                                             */
    MCD_CAL1_TYPE                     = 11, /**< CAL1 Correction Type.
		                                     *   0 = Peak Power. 1 = Integrated power.
                                             */
    MCD_PHASE_PETURBATION_APPLICATION = 7, /** Application of phase correction
                                            *  0 = applied ; 1 = not applied
                                            */
    MCD_CAL_2_CORR_MISSING            = 6, /**< CAL 2 correction
                                            *   missing.
                                            */
    MCD_CAL_2_CORR_IPF_DB             = 5, /**< CAL 2 correction
                                            *   applied was from
                                            *   the IPF DB.
                                            */
    MCD_POWER_SCALE_ERROR             = 4, /**< Error in power
                                            *   scaling.
                                            *   Only used in LRM mode.
                                            */
    MCD_ATT_CORR_MISSING              = 3, /**< Attitude
                                            *   correction missing.
                                            */

    MCD_PHASE_PETURBATION_MODE        = 1  /**< Phase peturbation mode.
                                            *   0 = CCAL1 ; 1 = IPFDB
                                            */
}
t_MCDFlagBit;

/** Bit ID's for the instrument config flag. See  TimeAndOrbitGroup#uj_Inst_config and L2IData#uj_Inst_config 

The two-bit integer assembled from the RX_CHAIN bits has the following values:

Value | Meaning
------|--------
0 | unknown
1 | chain1
2 | chain 2
3 | both chains

The two-bit integer assembled from the BANDWIDTH bits has the following values:

Value | Meaning
------|--------
0 | unknown
1 | 320 MHz
2 | 40 MHz

The two-bit integer assembled from the TRK_MODE bits has the following values:

Value | Meaning
------|--------
0 | unknown
1 | LRM
2 | SAR
3 | SARin

*/
typedef enum _t_InstConf
{
	RX_CHAIN_1 = 31, /**< Bit 1 for RX_CHAIN integer. */
	RX_CHAIN_0 = 30, /**< Bit 0 for RX_CHAIN integer. */
	SIRAL_ID = 29, /**< SIRAL side identifier. 0 = Nominal, 1 = Redundant. */
	BANDWIDTH_1 = 27, /**< Bit 1 for BANDWIDTH integer. */
	BANDWIDTH_0 = 26, /**< Bit 0 for BANDWIDTH integer. */
	TRK_MODE_1 = 23, /**< Bit 1 for TRK_MODE integer. */
	TRK_MODE_0 = 22, /**< Bit 0 for TRK_MODE integer. */
	EXTERNAL_CAL = 21, /**< Set if external calibration. */
	LOOP_STATUS = 19, /**< 0 = closed loop, 1 = open loop */
	LOSS_OF_ECHO = 18, /**< Set if loss of echo has occurred. */
	RT_ERROR = 17, /**< Set if the computing cycle took too long. */
	ECHO_SATURATION = 16, /**< Set if echo saturation was detected. */
	RX_BAND_ATT = 15, /**< Set if reception band attenuated. */
	CYCLE_ERROR = 14, /**< Set if there was an error from the cycle report. */
	STR_ATTREF_USED = 10 /**< Set if the STR_ATTREF file was used for mispointing. */
}
t_InstConf;

/** Bit ID's for the mode ID flag. See TimeAndOrbitGroup#ui_Mode_ID and L2IData#ui_Mode_ID

The six-bit integer assembled from the MODE_ID bits has the following values:

Value | Meaning
------|--------
1 | LRM
2 | SAR
3 | SARin
11 | CAL1 LRM
12 | CAL1 SAR
13 | CAL1 SARin
22 | CAL2 SAR
23 | CAL2 SARin
33 | CAL3

The two-bit integer assembled from the PLAT_ATT bits has the following values:

Value | Meaning
------|--------
0 | unknown
1 | Local normal pointing
2 | Yaw steering mode

 */
typedef enum _t_ModeID
{
	MODE_ID_5 = 15, /**< Bit 5 for MODE_ID integer */
	MODE_ID_4 = 14, /**< Bit 4 for MODE_ID integer */
	MODE_ID_3 = 13, /**< Bit 3 for MODE_ID integer */
	MODE_ID_2 = 12, /**< Bit 2 for MODE_ID integer */
	MODE_ID_1 = 11, /**< Bit 1 for MODE_ID integer */
	MODE_ID_0 = 10, /**< Bit 0 for MODE_ID integer */
	SIN_DEGRADED = 9, /**< Set to 1 if one receive chain is missing. */
	CAL4_MODE = 8, /**< Set to 1 for CAL 4 packets. */
	PLAT_ATT_1 = 6, /**< Bit 1 for PLAT_ATT integer */
	PLAT_ATT_0 = 5  /**< Bit 0 for PLAT_ATT integer */
}
t_ModeID;

/** Flag values for Star Tracker ID. See TimeAndOrbitGroup#i_ST_ID and L2IData#i_ST_ID */
typedef enum _t_STID {
	ST_NONE = 0, /**< No star tracker data used */
	ST_ATTREF = 4 /**< STR_ATTREF file used for product generation */
} t_STID;

/** Values for Surface Type field, see Corrections#uj_Surf_type and L2IData#uj_Surf_type. */
typedef enum _t_SurfaceType
{
    SURFACE_OPEN_OCEAN      = 0,        /**< Surface is open ocean. */
    SURFACE_CLOSED_SEA      = 1,        /**< Surface is closed sea. */
    SURFACE_CONTINENTAL_ICE = 2,        /**< Surface is continental ice. */
    SURFACE_LAND            = 3         /**< Surface is land. */
}
t_SurfaceType;

/** Bit IDs for Correction status flag. See Corrections#uj_Corr_status and L2IData#uj_Corr_status

@warning Some bits are only used in the L2i product.

 */
typedef enum _t_CorrectionStatusFlagBit
{
    COR_DRY_TROPO        = 31,        /**< Dry tropospheric correction
                                       *   called. */
    COR_WET_TROPO        = 30,        /**< Wet tropospheric correction
                                       *   called. */
    COR_INV_BARO         = 29,        /**< Inverse barometric correction
                                       *   called. */
    COR_DAC              = 28,        /**< Inverse barometric correction
                                       *   called. */
    COR_IONO_GIM         = 27,        /**< GIM ionospheric correction
                                       *   called. */
    COR_IONO_MODEL       = 26,        /**< Model ionospheric correction
                                       *   called. */
    COR_OT               = 25,        /**< Ocean Tide called. */
    COR_LPEOT            = 24,        /**< LPEOT called. */
    COR_OLT              = 23,        /**< Ocean Loading Tide called. */
    COR_SET              = 22,        /**< Solid Earth Tide called. */
    COR_GPT              = 21,        /**< Geocentric Polar Tide called. */
    COR_SURFACE_TYPE     = 20,        /**< Surface Type Flag called. */
    COR_ICE_CONC         = 19,        /**< Ice concentration model called. L2i product only. */
    COR_SNOW_DEPTH       = 18,        /**< Snow depth model called. L2i product only. */
    COR_SNOW_DENSITY     = 17,        /**< Snow density model called. L2i product only. */
    COR_MSS_MODEL        = 16,        /**< MSS model called. L2i product only. */
    COR_GEOID_MODEL      = 15,        /**< Geoid model called. L2i product only. */
    COR_ODLE_MODEL       = 14,        /**< ODLE model called. L2i product only. */
    COR_DEM_MODEL        = 13,        /**< DEM model called. L2i product only. */
    COR_SLOPE_MODEL      = 12,        /**< Slope model called. L2i product only. */
    COR_SSB              = 11          /**< SSB called/calculated. L2i product only. */
}
t_CorrectionStatusFlagBit;

/** Bit IDs for Correction error flags. See Corrections#uj_Corr_error and L2IData#uj_Corr_error

@warning Some bits are only used in the L2i product.
 */
typedef enum _t_CorrectionErrorFlagBit
{
    ERROR_DRY_TROPO        = 31,      /**< Dry tropospheric correction
                                       *   error. */
    ERROR_WET_TROPO        = 30,      /**< Wet tropospheric correction
                                       *   error. */
    ERROR_INV_BARO         = 29,      /**< Inverse barometric correction
                                       *   error. */
    ERROR_DAC              = 28,      /**< DAC correction
                                       *   error. */
    ERROR_IONO_GIM         = 27,      /**< GIM ionospheric correction
                                       *   error. */
    ERROR_IONO_MODEL       = 26,      /**< Model ionospheric correction
                                       *   error. */
    ERROR_OT               = 25,      /**< Ocean Tide error. */
    ERROR_LPEOT            = 24,      /**< LPEOT error. */
    ERROR_OLT              = 23,      /**< Ocean Loading Tide error. */
    ERROR_SET              = 22,      /**< Solid Earth Tide error. */
    ERROR_GPT              = 21,      /**< Geocentric Polar Tide error. */
    ERROR_SURFACE_TYPE     = 20,      /**< Surface Type Flag error. */
    ERROR_ICE_CONC         = 19,     /**< Ice conc error. L2i product only. */
    ERROR_SNOW_DEPTH       = 18,     /**< Snow depth error. L2i product only. */
    ERROR_SNOW_DENSITY     = 17,     /**< Snow density error. L2i product only. */
    ERROR_MSS_MODEL        = 16,     /**< MSS model error. L2i product only. */
    ERROR_GEOID_MODEL      = 15,     /**< Geoid model error. L2i product only. */
    ERROR_ODLE_MODEL       = 14,     /**< ODLE model error. L2i product only. */
    ERROR_DEM_MODEL        = 13,     /**< DEM model error. L2i product only. */
    ERROR_SLOPE_MODEL      = 12,     /**< Slope model error. L2i product only. */
    ERROR_SSB              = 11,      /**< SSB error. Used for L2 output only. */
    ERROR_SWH              = 10,      /**< SWH error. Used for L2 output only. */
    ERROR_WIND             = 9        /**< Wind speed error. Used for L2 output only. */
}
t_CorrectionErrorFlagBit;

#endif /* end of include guard: SHAREDFLAGS_H_74A678A2 */
