#ifndef JCSGETDSFILEOFFSETFROMHEADER_H_
#define JCSGETDSFILEOFFSETFROMHEADER_H_

/*-- pre-processor statements for conditional code --*/

/* %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
+

    System: UCL Cryosat IO Library

    Sub-system: Cryosat Specific

    Description: Header


    ----------------------------------------------
    Documentation cross reference:


    ----------------------------------------------
    This file lives in ---
    ./mssl_cryosat

    Coding by:
    David J Brockley
    http://cryosat.mssl.ucl.ac.uk/public

    ----------------------------------------------
    Filename              :     $RCSfile: jCSGetDSFileOffsetFromHeader.h,v $
    CVS Version Number    :     $Revision: 1.2 $
    Last Update           :     $Date: 2014/12/01 11:30:14 $
    What String           :     @(#)$Id: jCSGetDSFileOffsetFromHeader.h,v 1.2 2014/12/01 11:30:14 djb Exp $
    Log                   :
                                $Log: jCSGetDSFileOffsetFromHeader.h,v $
                                Revision 1.2  2014/12/01 11:30:14  djb
                                Pre-testing for release v2.1

                                Revision 1.1  2010/07/16 14:37:56  djb
                                Port in CryoSat tools from internal branch.



    -----------------------------------------------------------
    This file contains the Unpublished Intellectual Property of
    University College London and All Rights Are Reserved.
        Copyright (c) University College London, 2005, 2010
    -----------------------------------------------------------
-
*/

#pragma ident "@(#)$Id: jCSGetDSFileOffsetFromHeader.h,v 1.2 2014/12/01 11:30:14 djb Exp $ MSSL"

/**
 * @file   jCSGetDSFileOffsetFromHeader.h
 *
 * @brief  Get the offset of a dataset from the header.
 *
 *
 */

/*-- pre-processor statements --*/

/*-- standard C headers --*/
#include <stdio.h>

/*-- programmer created headers --*/
#include "CS_Defines.h"

/*-- constant and macro headers --*/

/*-- type definitions --*/

/*-- global and external variable declarations --*/

/*-- module private (static) variable declarations --*/

/*-- functions --*/

/**
 * Get the offset of a dataset from the header.
 *
 * This function retrieves the offset into a file at which a specific
 * dataset mentioned in the ASCII header can be found. If both of the
 * output parameters are NULL, this function can be used to check for
 * the presence of a specific type of dataset within a file.
 *
 * @ingroup CS_SHARED_IO_API_HIGH
 *
 * @param pt_dataset_file_offset Pointer to an fpos_t into which the
 * offset will be written. May be NULL.
 * @param pj_num_records Pointer to an integer into which the number
 * of records in the dataset will be written. May be NULL.
 * @param s_filename The filename of the file to query.
 * @param t_ds_name An enumerated type describing the type of data to
 * look for in the file.
 * @param pj_actual_ds Filled with the type of DS found. This is made as
 * generic as possible e.g. CS_L2_DS_NAME_ANY rather than CS_L2_DS_NAME_LRM.
 *
 * @return EXIT_SUCCESS if all went well. EXIT_FAILURE otherwise.
 */
long int jCSGetDSFileOffsetFromHeader(fpos_t*    pt_dataset_file_offset,
                                       long int*  pj_num_records,
                                       char*      s_filename,
                                       CS_DS_NAME t_ds_name,
                                       long int*  pj_actual_ds);

#endif /* ifndef JCSGETDSFILEOFFSETFROMHEADER_H_ */
