#ifndef J_FILL_L1B_STRUCT_FROM_FILE_H
#define J_FILL_L1B_STRUCT_FROM_FILE_H

/* %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
+

    System: UCL Cryosat IO Library

    Sub-system: Cryosat Specific

    Description:
    Include File.

    ----------------------------------------------
    Documentation cross reference:
    [PROD-FMT] Product Format Specification v4.5 20/04/2009 CS-RS-ACS-GS-5106

    ----------------------------------------------
    This file lives in ---
    ./mssl_cryosat

    Coding by:
    David Brockley
    http://cryosat.mssl.ucl.ac.uk/public

    ----------------------------------------------
    Filename              :     $RCSfile: jFillL1bStructFromFile.h,v $
    CVS Version Number    :     $Revision: 1.2 $
    Last Update           :     $Date: 2014/12/01 11:30:14 $
    What String           :     @(#)$Id: jFillL1bStructFromFile.h,v 1.2 2014/12/01 11:30:14 djb Exp $
    Log                   :
                                $Log: jFillL1bStructFromFile.h,v $
                                Revision 1.2  2014/12/01 11:30:14  djb
                                Pre-testing for release v2.1

                                Revision 1.1  2010/07/16 14:37:56  djb
                                Port in CryoSat tools from internal branch.


    ---------------------------------------------------------------------------
    This file is the Unpublished Intellectual
    Property of University College London and
    All Rights are Reserved.

    Copyright (c) University College London, 2005, 2010
    ---------------------------------------------------------------------------
-
*/

#include <stdio.h>
#include "L1bStructure.h"
#include "ptCSGetFileHandle.h"

/**
 * @file   jFillL1bStructFromFile.h
 *
 * @brief  Low-level functions to read Cryosat Level 1b data in LRM,
 * SAR, or SARin modes.
 *
 *
 */

/**
 * Read a Cryosat Level 1b LRM mode record from disk into a
 * pre-allocated structure.
 *
 * @ingroup CS_L1B_IO_API_LOW
 *
 * @param p_ToFill Pointer to a pre-allocated structure to fill.
 * @param pt_input File pointer to the record to read.
 * @param j_Baseline Baseline (version) of the product format expected.
 *
 * @return EXIT_SUCCESS if the record was correctly read, EXIT_FAILURE otherwise.
 */
long int jFillL1bLRMStructFromFile(L1B_LRM* p_ToFill,
                                    FILE*    pt_input , BASELINE j_Baseline);

/**
 * Read a Cryosat Level 1b SAR mode record from disk into a
 * pre-allocated structure.
 *
 * @ingroup CS_L1B_IO_API_LOW
 *
 * @param p_ToFill Pointer to a pre-allocated structure to fill.
 * @param pt_input File pointer to the record to read.
 * @param j_Baseline Baseline (version) of the product format expected.
 *
 * @return EXIT_SUCCESS if the record was correctly read, EXIT_FAILURE otherwise.
 */

long int jFillL1bSARStructFromFile(L1B_SAR* p_ToFill,
                                    FILE*    pt_input , BASELINE j_Baseline);

/**
 * Read a Cryosat Level 1b SARin mode record from disk into a
 * pre-allocated structure.
 *
 * @ingroup CS_L1B_IO_API_LOW
 *
 * @param p_ToFill Pointer to a pre-allocated structure to fill.
 * @param pt_input File pointer to the record to read.
 * @param j_Baseline Baseline (version) of the product format expected.
 *
 * @return EXIT_SUCCESS if the record was correctly read, EXIT_FAILURE otherwise.
 */

long int jFillL1bSARINStructFromFile( L1B_SARIN* p_ToFill,
                                      FILE*      pt_input, BASELINE j_Baseline );

#endif /* ifndef J_FILL_L1B_STRUCT_FROM_FILE_H */
