#ifndef _JFILLL2STRUCTFROMFILE_H
#define _JFILLL2STRUCTFROMFILE_H

/* %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
+

    System: UCL Cryosat IO Library

    Sub-system: Cryosat specific

    Description:
    Include File.

    ----------------------------------------------
    Documentation cross reference:
    [C2_FMT] L2 Products Format Specification v2.5 09/06/2009 CS-RS-ACS-GS-5123

    ----------------------------------------------
    This file lives in ---
    ./mssl_cryosat

    Coding by:
    David J Brockley
    http://cryosat.mssl.ucl.ac.uk/public

    ----------------------------------------------
    Filename              :     $RCSfile: jFillL2StructFromFile.h,v $
    CVS Version Number    :     $Revision: 1.2 $
    Last Update           :     $Date: 2014/12/01 11:30:14 $
    What String           :     @(#)$Id: jFillL2StructFromFile.h,v 1.2 2014/12/01 11:30:14 djb Exp $
    Log                   :
                                $Log: jFillL2StructFromFile.h,v $
                                Revision 1.2  2014/12/01 11:30:14  djb
                                Pre-testing for release v2.1

                                Revision 1.1  2010/07/16 14:37:56  djb
                                Port in CryoSat tools from internal branch.


    ---------------------------------------------------------------------------
    This file is the Unpublished Intellectual
    Property of University College London and
    All Rights are Reserved.

    Copyright (c) University College London, 2005, 2010
    ---------------------------------------------------------------------------
-
*/

/**
 * @file   jFillL2StructFromFile.h
 *
 * @brief  Low-level functions to read Cryosat Level 2 data.
 *
 *
 */

#pragma ident "@(#)$Id: jFillL2StructFromFile.h,v 1.2 2014/12/01 11:30:14 djb Exp $ MSSL"

/* INCLUDE FILES */

/*-- standard C headers --*/
#include <stdio.h>

/*-- programmer created headers --*/
#include "L2Structure.h"
#include "ptCSGetFileHandle.h"
/*-- global and external variable declarations --*/

/* STRUCTURES */

/* FUNCTIONS */

/*-- local function prototypes --*/

/**
 * Read one record of Cryosat Level 2 data from a file.
 *
 * @ingroup CS_L2_IO_API_LOW
 *
 * @param pt_Level2 Pointer to a L2Data struct to fill with data.
 * @param pt_File Pointer to the file to read from.
 * @param j_Baseline Baseline (version) of the product format expected.
 *
 * @return If reading is successful EXIT_SUCCESS, otherwise EXIT_FAILURE.
 */
long int
jFillL2StructFromFile(L2Data* pt_Level2,
                       FILE*   pt_File , BASELINE j_Baseline);

#endif /* _JFILLL2STRUCTFROMFILE_H */
