#ifndef PTCSGETFILEHANDLE_H
#define PTCSGETFILEHANDLE_H

/*-- pre-processor statements for conditional code --*/

/* %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
+

    System: UCL Cryosat IO Library

    Sub-system: Cryosat Specific

    Description: Header


    ----------------------------------------------
    Documentation cross reference:


    ----------------------------------------------
    This file lives in ---
    ./mssl_cryosat

    Coding by:
    David J Brockley
    http://cryosat.mssl.ucl.ac.uk/public

    ----------------------------------------------
    Filename              :     $RCSfile: ptCSGetFileHandle.h,v $
    CVS Version Number    :     $Revision: 1.3 $
    Last Update           :     $Date: 2015/06/02 11:07:44 $
    What String           :     @(#)$Id: ptCSGetFileHandle.h,v 1.3 2015/06/02 11:07:44 djb Exp $
    Log                   :
                                $Log: ptCSGetFileHandle.h,v $
                                Revision 1.3  2015/06/02 11:07:44  djb
                                Preparing for release 2.2

                                Revision 1.2  2014/12/01 11:30:14  djb
                                Pre-testing for release v2.1

                                Revision 1.1  2010/07/16 14:37:56  djb
                                Port in CryoSat tools from internal branch.


    -----------------------------------------------------------
    This file contains the Unpublished Intellectual Property of
    University College London and All Rights Are Reserved.
        Copyright (c) University College London, 2005, 2010
    -----------------------------------------------------------
-
*/

#pragma ident "@(#)$Id: ptCSGetFileHandle.h,v 1.3 2015/06/02 11:07:44 djb Exp $ MSSL"

/*-- pre-processor statements --*/

/*-- standard C headers --*/
#include <stdio.h>

/*-- programmer created headers --*/

/*-- constant and macro headers --*/

/*-- type definitions --*/

/*-- global and external variable declarations --*/

/*-- module private (static) variable declarations --*/

/*-- functions --*/

/**< Identifiers to use to select products conforming to a specific baseline format. */
typedef enum _BASELINE
{
    BASELINE_UNKNOWN, /**< Use for variable initialisation only. */
    BASELINE_A, /**< Attempt to read Baseline A */
    BASELINE_B, /**< Attempt to read Baseline B */
    BASELINE_BC, /**< Attempt to read Baseine BC (internal and selected projects only) */
    BASELINE_C /**< Attempt to read Baseline C */
} BASELINE;

/**
 * @file   ptCSGetFileHandle.h
 *
 * @brief  Provide an opaque object that can store the information
 * necessary to parse files.
 *
 *
 */

/**< File information struture/ */
typedef struct _t_cs_fileinfo
{
    FILE*     pt_filepointer; /**< Filepointer to this file. */
    long int  j_num_datasets; /**< Number of datasets in this file. */
    fpos_t*   pat_data_start_offsets; /**< Array of byte offsets to datasets. */
    long int* paj_num_records; /**< Array of counts of records in each dataset. */
    long int  j_type; /**< Filetype of this file. */
    BASELINE  j_baseline; /**< Basline that the product format of this file conforms to. */
}
t_cs_fileinfo;

/**
 * Cryosat File Handle Type.
 *
 * An opaque object that contains the information necessary for the
 * Cryosat file handling library to access the file.
 */
typedef t_cs_fileinfo* t_cs_filehandle;

/** Obtain a handle to the file with the given filename that is
 * needed to call the other functions in this library.
 *
 * @ingroup CS_SHARED_IO_API_HIGH
 *
 * @param s_filename The name of the file to obtain a handle upon.
 * @param j_baseline The baseline (version) of the product format expected.
 * @return t_cs_filehandle Equal to NULL if a handle could not be
 * obtained.
 *
 * */
t_cs_filehandle ptCSGetFileHandle(char* s_filename, BASELINE j_baseline);

#endif /* ifndef PTCSGETFILEHANDLE_H */
