#ifndef PTCSGETL1B_H_
#define PTCSGETL1B_H_

/*-- pre-processor statements for conditional code --*/

/* %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
+

    System: UCL Cryosat IO Library

    Sub-system: Cryosat Specific

    Description: Header


    ----------------------------------------------
    Documentation cross reference:


    ----------------------------------------------
    This file lives in ---
    ./mssl_cryosat

    Coding by:
    David J Brockley
    http://cryosat.mssl.ucl.ac.uk/public

    ----------------------------------------------
    Filename              :     $RCSfile: ptCSGetL1b.h,v $
    CVS Version Number    :     $Revision: 1.1 $
    Last Update           :     $Date: 2010/07/16 14:37:56 $
    What String           :     @(#)$Id: ptCSGetL1b.h,v 1.1 2010/07/16 14:37:56 djb Exp $
    Log                   :
                                $Log: ptCSGetL1b.h,v $
                                Revision 1.1  2010/07/16 14:37:56  djb
                                Port in CryoSat tools from internal branch.


    -----------------------------------------------------------
    This file contains the Unpublished Intellectual Property of
    University College London and All Rights Are Reserved.
        Copyright (c) University College London, 2005, 2010
    -----------------------------------------------------------
-
*/

#pragma ident "@(#)$Id: ptCSGetL1b.h,v 1.1 2010/07/16 14:37:56 djb Exp $ MSSL"

/*-- pre-processor statements --*/

/*-- standard C headers --*/

/*-- programmer created headers --*/
#include "L1bStructure.h"
#include "ptCSGetFileHandle.h"

/*-- constant and macro headers --*/

/*-- type definitions --*/

/*-- global and external variable declarations --*/

/*-- module private (static) variable declarations --*/

/*-- functions --*/

/**
 * @file   ptCSGetL1b.h
 *
 * @brief  Functions to read Cryosat Level 1b data files.
 *
 *
 */

/**
 * Read records from a Cryosat Level 1b LRM mode formatted file.
 *
 * This function may be called to read one or more records from a
 * Cryosat Level 1b LRM file. Both complete and interim files are supported
 * (files with or without an MPH and SPH). It is possible to request
 * that reading starts at some distance into the file and also to read
 * only part of the file. Memory to hold the records may either be
 * allocated in advance or by the function.
 *
 * @ingroup CS_L1B_IO_API_HIGH
 *
 * @param t_handle A handle to the file returned from a call to ptCSGetFileHandle().
 * @param j_dataset_index The index (from zero) of the dataset to
 * return. Must be zero at present.
 * @param uk_num_records The number of records to read from the
 * file. If zero, read the whole file.
 * @param uk_skip_records The number of records to skip at the start
 * of the file.
 * @param pt_data A pointer to one or more structures of type
 * L1B_LRM. If this pointer is non-NULL then the memory pointed to will
 * be filled with the data read. If this pointer is NULL then memory
 * will be allocated by the function and it is the calling routines
 * responsibility to free that memory with a call to free().
 *
 * @return A pointer to the memory that has been filled with the data
 * read from the file, or NULL in the case of error.
 * If pt_data is non-NULL then the return value is
 * pt_data. Otherwise it is a pointer to newly allocated memory.
 */
L1B_LRM* ptCSGetL1bLRM( t_cs_filehandle        t_handle,
                        long int               j_dataset_index,
                        unsigned long long int uk_num_records,
                        unsigned long long int uk_skip_records,
                        L1B_LRM*               pt_data );

/**
 * Read records from a Cryosat Level 1b SAR mode formatted file.
 *
 * This function may be called to read one or more records from a
 * Cryosat Level 1b SAR file. Both complete and interim files are supported
 * (files with or without an MPH and SPH). It is possible to request
 * that reading starts at some distance into the file and also to read
 * only part of the file. Memory to hold the records may either be
 * allocated in advance or by the function.
 *
 * @ingroup CS_L1B_IO_API_HIGH
 *
 * @param t_handle A handle to the file returned from a call to ptCSGetFileHandle().
 * @param j_dataset_index The index (from zero) of the dataset to
 * return. Must be zero at present.
 * @param uk_num_records The number of records to read from the
 * file. If zero, read the whole file.
 * @param uk_skip_records The number of records to skip at the start
 * of the file.
 * @param pt_data A pointer to one or more structures of type
 * L1B_SAR. If this pointer is non-NULL then the memory pointed to will
 * be filled with the data read. If this pointer is NULL then memory
 * will be allocated by the function and it is the calling routines
 * responsibility to free that memory with a call to free().
 *
 * @return A pointer to the memory that has been filled with the data
 * read from the file, or NULL in the case of error.
 * If pt_data is non-NULL then the return value is
 * pt_data. Otherwise it is a pointer to newly allocated memory.
 */
L1B_SAR* ptCSGetL1bSAR( t_cs_filehandle        t_handle,
                        long int               j_dataset_index,
                        unsigned long long int uk_num_records,
                        unsigned long long int uk_skip_records,
                        L1B_SAR*               pt_data );

/**
 * Read records from a Cryosat Level 1b SARin mode formatted file.
 *
 * This function may be called to read one or more records from a
 * Cryosat Level 1b SARin file. Both complete and interim files are supported
 * (files with or without an MPH and SPH). It is possible to request
 * that reading starts at some distance into the file and also to read
 * only part of the file. Memory to hold the records may either be
 * allocated in advance or by the function.
 *
 * @ingroup CS_L1B_IO_API_HIGH
 *
 * @param t_handle A handle to the file returned from a call to ptCSGetFileHandle().
 * @param j_dataset_index The index (from zero) of the dataset to
 * return. Must be zero at present.
 * @param uk_num_records The number of records to read from the
 * file. If zero, read the whole file.
 * @param uk_skip_records The number of records to skip at the start
 * of the file.
 * @param pt_data A pointer to one or more structures of type
 * L1B_SARIN. If this pointer is non-NULL then the memory pointed to will
 * be filled with the data read. If this pointer is NULL then memory
 * will be allocated by the function and it is the calling routines
 * responsibility to free that memory with a call to free().
 *
 * @return A pointer to the memory that has been filled with the data
 * read from the file or NULL in the case of error.
 * If pt_data is non-NULL then the return value is
 * pt_data. Otherwise it is a pointer to newly allocated memory.
 *
 */
L1B_SARIN* ptCSGetL1bSARIN( t_cs_filehandle        t_handle,
                            long int               j_dataset_index,
                            unsigned long long int uk_num_records,
                            unsigned long long int uk_skip_records,
                            L1B_SARIN*             pt_data );

/**
 * \example examples/cs_l1b_io_example.c
 *
 * \latexonly
 * \label{ex2}
 * \endlatexonly
 *
 * This is an example of the most common way to use the Cryosat IO
 * Library. The entire L1b file is read from the filename specified on
 * the commandline. The day field is printed from the data read in as
 * a test that the file has been read correctly. No complex error
 * handling is perfomed.
 *
 */

#endif /* ifndef PTCSGETL1B_H_ */
