/*-- pre-processor statements for conditional code --*/

/* %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
+

    System: UCL Cryosat IO Library

    Sub-system: Cryosat Specific

    Description: Get L2I records from file.


    ----------------------------------------------
    Documentation cross reference:


    ----------------------------------------------
    This file lives in ---
    ./mssl_cryosat

    Coding by:
    David J Brockley
    http://cryosat.mssl.ucl.ac.uk/public

    ----------------------------------------------
    Filename              :     $RCSfile: ptCSGetL2I.c,v $
    CVS Version Number    :     $Revision: 1.3 $
    Last Update           :     $Date: 2015/06/02 11:07:44 $
    What String           :     @(#)$Id: ptCSGetL2I.c,v 1.3 2015/06/02 11:07:44 djb Exp $
    Log                   :
                                $Log: ptCSGetL2I.c,v $
                                Revision 1.3  2015/06/02 11:07:44  djb
                                Preparing for release 2.2

                                Revision 1.2  2014/12/01 11:30:14  djb
                                Pre-testing for release v2.1

                                Revision 1.1  2010/07/16 14:37:56  djb
                                Port in CryoSat tools from internal branch.


    ----------------------------------------------
    Routines:
    ptCSGetL2I

    -----------------------------------------------------------
    This file contains the Unpublished Intellectual Property of
    University College London and All Rights Are Reserved.
        Copyright (c) University College London, 2005, 2010
    -----------------------------------------------------------
-
*/

/**
 * @file   ptCSGetL2I.c
 *
 * @brief  Implementation of functions to read Cryosat Level 2 data files.
 *
 *
 */

#pragma ident "@(#)$Id: ptCSGetL2I.c,v 1.3 2015/06/02 11:07:44 djb Exp $ MSSL"

/*-- pre-processor statements --*/

/*-- standard C headers --*/
#include <stdlib.h>

/*-- programmer created headers --*/
#include "ptCSGetL2I.h"
#include "CS_Defines.h"
#include "jFillL2IStructFromFile.h"

/*-- constant and macro headers --*/

/*-- type definitions --*/

/*-- global and external variable declarations --*/

/*-- module private (static) variable declarations --*/

/*-- functions --*/

L2IData*
ptCSGetL2I( t_cs_filehandle        t_handle,
            long int               j_dataset_index,
            unsigned long long int uk_num_records,
            unsigned long long int uk_skip_records,
            L2IData*               pt_data )
{
    /** Total number of records to read from the file */
    unsigned long long int uk_records_to_read = 0;

    /** Loop counter for file reading */
    unsigned long long int uk_count = 0;

    /** The index of the current record being read */
    unsigned long long int uk_read_record = 0;

    /** Return value of function calls */
    long int j_result = 0;

    if( t_handle == NULL )
    {
        return NULL;
    }

    if( t_handle->pt_filepointer == NULL )
    {
        return NULL;
    }

    if( t_handle->j_num_datasets <= j_dataset_index )
    {
        return NULL;
    }

    if( t_handle->j_type != CS_L2I_DS_NAME_ANY )
     {
         printf( "File is not an L2I filetype.\n" );
         return NULL;
     }

    if( pt_data == NULL )
    {
        if( uk_num_records == 0 )
        {
            /* Determine number of records in entire file */
            uk_num_records = t_handle->paj_num_records[ j_dataset_index ];
        }

        if( uk_skip_records != 0 )
        {
            uk_records_to_read = uk_num_records - uk_skip_records;
        }
        else
        {
            uk_records_to_read = uk_num_records;
        }

        pt_data = malloc( sizeof( L2IData ) * uk_records_to_read );

        if( pt_data == NULL )
        {
            return NULL;
        }
    }

    /* Put the filepointer at the start of the data */
    j_result = fsetpos( t_handle->pt_filepointer,
                        &t_handle->pat_data_start_offsets[ j_dataset_index ] );

    if( j_result != EXIT_SUCCESS )
    {
        return NULL;
    }

    /* Read and fill */
    for( uk_count = uk_skip_records; uk_count < uk_num_records; uk_count++ )
    {
        uk_read_record = uk_count - uk_skip_records;

        j_result       = jFillL2IStructFromFile(&pt_data[ uk_read_record ],
                                                 t_handle->pt_filepointer , t_handle->j_baseline);

        if( j_result != EXIT_SUCCESS )
        {
            return NULL;
        }
    }

    return pt_data;
} /* ptCSGetL2I */
