#ifndef PTCSGETL2I_H_
#define PTCSGETL2I_H_

/*-- pre-processor statements for conditional code --*/

/* %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
+

    System: UCL Cryosat IO Library

    Sub-system: Cryosat Specific

    Description: Header


    ----------------------------------------------
    Documentation cross reference:


    ----------------------------------------------
    This file lives in ---
    ./mssl_cryosat

    Coding by:
    David J Brockley
    http://cryosat.mssl.ucl.ac.uk/public

    ----------------------------------------------
    Filename              :     $RCSfile: ptCSGetL2I.h,v $
    CVS Version Number    :     $Revision: 1.2 $
    Last Update           :     $Date: 2015/06/02 11:07:44 $
    What String           :     @(#)$Id: ptCSGetL2I.h,v 1.2 2015/06/02 11:07:44 djb Exp $
    Log                   :
                                $Log: ptCSGetL2I.h,v $
                                Revision 1.2  2015/06/02 11:07:44  djb
                                Preparing for release 2.2

                                Revision 1.1  2010/07/16 14:37:56  djb
                                Port in CryoSat tools from internal branch.


    -----------------------------------------------------------
    This file contains the Unpublished Intellectual Property of
    University College London and All Rights Are Reserved.
        Copyright (c) University College London, 2005, 2010
    -----------------------------------------------------------
-
*/

#pragma ident "@(#)$Id: ptCSGetL2I.h,v 1.2 2015/06/02 11:07:44 djb Exp $ MSSL"

/*-- pre-processor statements --*/

/*-- standard C headers --*/

/*-- programmer created headers --*/
#include "L2IStructure.h"
#include "ptCSGetFileHandle.h"

/*-- constant and macro headers --*/

/*-- type definitions --*/

/*-- global and external variable declarations --*/

/*-- module private (static) variable declarations --*/

/*-- functions --*/

/**
 * @file   ptCSGetL2I.h
 *
 * @brief  Functions to read Cryosat Level 2 data files.
 *
 *
 */

/**
 * Read records from a Cryosat Level 2 Intermediate formatted file.
 *
 * This function may be called to read one or more records from a
 * Cryosat Level 2 Intermediate file. Both complete and interim files are supported
 * (files with or without an MPH and SPH). It is possible to request
 * that reading starts at some distance into the file and also to read
 * only part of the file. Memory to hold the records may either be
 * allocated in advance or by the function.
 *
 * @ingroup CS_L2_IO_API_HIGH
 *
 * @param t_handle A handle to the file returned from a call to ptCSGetFileHandle().
 * @param j_dataset_index The index (from zero) of the dataset to
 * return. Must be zero at present.
 * @param uk_num_records The number of records to read from the
 * file. If zero, read the whole file.
 * @param uk_skip_records The number of records to skip at the start
 * of the file.
 * @param pt_data A pointer to one or more structures of type
 * L2IData. If this pointer is non-NULL then the memory pointed to will
 * be filled with the data read. If this pointer is NULL then memory
 * will be allocated by the function and it is the calling routines
 * responsibility to free that memory with a call to free().
 *
 * @return A pointer to the memory that has been filled with the data
 * read from the file, or NULL in the case of error.
 * If pt_data is non-NULL then the return value is
 * pt_data. Otherwise it is a pointer to newly allocated memory.
 *
 * \callgraph
 * \callergraph
 */
L2IData* ptCSGetL2I( t_cs_filehandle        t_handle,
                     long int               j_dataset_index,
                     unsigned long long int uk_num_records,
                     unsigned long long int uk_skip_records,
                     L2IData*               pt_data );

/**
 * \example examples/cs_l2i_io_example.c
 *
 * \latexonly
 * \label{ex1}
 * \endlatexonly
 *
 * This is an example of the most common way to use the Cryosat IO
 * Library. The entire L2I file is read from the filename specified on
 * the commandline. The day field is printed from the data read in as
 * a test that the file has been read correctly. No complex error
 * handling is perfomed.
 *
 */

#endif /* ifndef PTCSGETL2I_H_ */
