/*-- pre-processor statements for conditional code --*/

/* %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
+

    System: UCL Cryosat IO Library

    Sub-system: MSSL Shared

    Description:
    Manipulate bits by their index within the word. Bit 0 is the LSB.

    ----------------------------------------------
    Documentation cross reference:


    ----------------------------------------------
    This file lives in ---
    ./mssl_shared

    Coding by:
    David J Brockley
    http://cryosat.mssl.ucl.ac.uk/public

    ----------------------------------------------
    Filename              :     $RCSfile: BitmaskUtilities.c,v $
    CVS Version Number    :     $Revision: 1.3 $
    Last Update           :     $Date: 2015/06/02 11:07:44 $
    What String           :     @(#)$Id: BitmaskUtilities.c,v 1.3 2015/06/02 11:07:44 djb Exp $
    Log                   :
                                $Log: BitmaskUtilities.c,v $
                                Revision 1.3  2015/06/02 11:07:44  djb
                                Preparing for release 2.2

                                Revision 1.2  2010/08/27 09:22:59  djb
                                Prototype changes to fix on 64 bit machines and to correct the size of the quality flag in L2.

                                Revision 1.1  2010/07/16 14:37:56  djb
                                Port in CryoSat tools from internal branch.

                                Revision 1.2  2005/10/13 14:04:46  djb
                                More updates for 0.3 release

                                Revision 1.1  2005/10/12 13:40:26  djb
                                Updates for 0.3 release.



    ----------------------------------------------
    Routines:
    iCheckBitLong
    iCheckBitLongLong
    iCheckBitShort
    vClearBitLong
    vClearBitLongLong
    vClearBitShort
    vSetBitLong
    vSetBitLongLong
    vSetBitShort

    -----------------------------------------------------------
    This file contains the Unpublished Intellectual Property of
    University College London and All Rights Are Reserved.
        Copyright (c) University College London, 2005
    -----------------------------------------------------------
-
*/

/**
 * @file   BitmaskUtilities.c
 *
 * @brief  Implementation of functions to manipulate bitmasks.
 *
 *
 */

#pragma ident "@(#)$Id: BitmaskUtilities.c,v 1.3 2015/06/02 11:07:44 djb Exp $ MSSL"

/*-- pre-processor statements --*/

/*-- standard C headers --*/
#include <assert.h>

/*-- programmer created headers --*/
#include "BitmaskUtilities.h"
#undef REVERSE_BITS
#include "bits.h"

/*-- constant and macro headers --*/

/*-- type definitions --*/

/*-- global and external variable declarations --*/

/*-- module private (static) variable declarations --*/

/*-- functions --*/

/*
 * DEFINITION OF TERMS
 *
 * The LSB is identified as bit 0. Setting bit 0
 * in this format for an uint16_t gives a value of 1. Setting
 * bit 15 should give a value of 32768.
 *
 */

void
vSetBitShort( uint16_t* pBitmask,
              uint16_t  bit )
{
    assert( bit < ( sizeof( uint16_t ) * 8 ) );
    assert( pBitmask != 0 );

    set_bit( pBitmask, bit );
}

int16_t
iCheckBitShort( uint16_t* pBitmask,
                uint16_t  bit )
{
    assert( bit < ( sizeof( uint16_t ) * 8 ) );
    assert( pBitmask != 0 );

    return ( test_bit( pBitmask, bit ) ) ? 1 : 0;
}

void
vClearBitShort( uint16_t* pBitmask,
                uint16_t  bit )
{
    assert( bit < ( sizeof( uint16_t ) * 8 ) );
    assert( pBitmask != 0 );

    clr_bit( pBitmask, bit );
}

void
vSetBitLong( uint32_t* pBitmask,
             uint16_t bit )
{
    assert( bit < ( sizeof( uint32_t ) * 8 ) );
    assert( pBitmask != 0 );

    set_bit( pBitmask, bit );
}

int16_t
iCheckBitLong( uint32_t* pBitmask,
               uint16_t bit )
{
    int32_t j_result = 0;

    assert( bit < ( sizeof( uint32_t ) * 8 ) );
    assert( pBitmask != 0 );

    return test_bit( pBitmask, bit ) ? 1 : 0;
}

void
vClearBitLong( uint32_t* pBitmask,
               uint16_t bit )
{
    assert( bit < ( sizeof( uint32_t ) * 8 ) );
    assert( pBitmask != 0 );

    clr_bit( pBitmask, bit );
}

void
vSetBitLongLong( uint64_t* pBitmask,
                 uint16_t      bit )
{
    assert( bit < ( sizeof( uint64_t ) * 8 ) );
    assert( pBitmask != 0 );

    set_bit( pBitmask, bit );
}

int16_t
iCheckBitLongLong( uint64_t* pBitmask,
                   uint16_t      bit )
{
    assert( bit < ( sizeof( uint64_t ) * 8 ) );
    assert( pBitmask != 0 );

    return ( test_bit( pBitmask, bit ) ) ? 1 : 0;
}

void
vClearBitLongLong( uint64_t* pBitmask,
                   uint16_t      bit )
{
    assert( bit < ( sizeof( uint64_t ) * 8 ) );
    assert( pBitmask != 0 );

    clr_bit( pBitmask, bit );
}
