#ifndef _BITS_H
#define _BITS_H

/* %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
+

    System: UCL Cryosat IO Library

    Sub-system: MSSL Shared

    Description:
    This file contains the definitions of:  bit field access macros.

    ----------------------------------------------
    Documentation cross reference

    ----------------------------------------------
    This file lives in ---
    ./mssl_shared

    Coding by:
    David J Brockley
    http://cryosat.mssl.ucl.ac.uk/public

     --------------------------------------------
    Filename              :     $RCSfile: bits.h,v $
    CVS Version Number    :     $Revision: 1.1 $
    Last Update           :     $Date: 2010/07/16 14:37:56 $
    What String           :     @(#)$Id: bits.h,v 1.1 2010/07/16 14:37:56 djb Exp $
    Log                   :
                                $Log: bits.h,v $
                                Revision 1.1  2010/07/16 14:37:56  djb
                                Port in CryoSat tools from internal branch.

                                Revision 1.2  2005/10/13 14:04:46  djb
                                More updates for 0.3 release

                                Revision 1.1  2005/10/12 13:40:26  djb
                                Updates for 0.3 release.


     --------------------------------------------
    Routines:
    test_bit
    set_bit
    clr_bit

    -----------------------------------------------------------
    This file contains the Unpublished Intellectual Property of
    University College London and All Rights Are Reserved.
        Copyright (c) University College London, 2005
    -----------------------------------------------------------
-
*/
#pragma ident "@(#)$Id: bits.h,v 1.1 2010/07/16 14:37:56 djb Exp $	 MSSL"

/*
 * Define bit manipulation macros for the scheme where 0 is the LSB
 */
#ifdef WORDS_BIGENDIAN

#define test_bit( p_word, bit ) ( *( p_word ) & ( 1 << bit ) )
#define set_bit( p_word, bit ) ( *( p_word ) |= ( 1 << bit ) )
#define clr_bit( p_word, bit ) ( *( p_word ) &= ~( 1 << bit ) )

#else

#define test_bit( p_word, bit ) ( ( (char*)p_word )[ ( bit >> 3 ) ] & ( 1 << ( bit % 8 ) ) )
#define set_bit( p_word, bit ) ( ( (char*)p_word )[ ( bit >> 3 ) ] |= ( 1 << ( bit % 8 ) ) )
#define clr_bit( p_word, bit ) ( ( (char*)p_word )[ ( bit >> 3 ) ] &= ~( 1 << ( bit % 8 ) ) )

#endif

#endif /* ifndef _BITS_H */
