/*-- pre-processor statements for conditional code --*/

/* %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
+

    System: UCL Cryosat IO Library

    Sub-system: MSSL Shared

    Description:
    Get a file size as a long long.

    ----------------------------------------------
    Documentation cross reference:


    ----------------------------------------------
    This file lives in ---
    ./mssl_shared

    Coding by:
    David J Brockley
    http://cryosat.mssl.ucl.ac.uk/public

    ----------------------------------------------
    Filename              :     $RCSfile: kGetFileSize.c,v $
    CVS Version Number    :     $Revision: 1.1 $
    Last Update           :     $Date: 2010/07/16 14:37:56 $
    What String           :     @(#)$Id: kGetFileSize.c,v 1.1 2010/07/16 14:37:56 djb Exp $
    Log                   :
                                $Log: kGetFileSize.c,v $
                                Revision 1.1  2010/07/16 14:37:56  djb
                                Port in CryoSat tools from internal branch.

                                Revision 1.3  2005/10/12 13:40:26  djb
                                Updates for 0.3 release.

                                Revision 1.2  2005/09/26 09:50:20  djb
                                Changes to documentation.

                                Revision 1.1.1.1  2005/09/23 13:51:56  djb
                                Initial import of sources to CVS.



    ----------------------------------------------
    Routines:
    kGetFileSize - Get the size of a file

    -----------------------------------------------------------
    This file contains the Unpublished Intellectual Property of
    University College London and All Rights Are Reserved.
        Copyright (c) University College London, 2005
    -----------------------------------------------------------
-
*/

#pragma ident "@(#)$Id: kGetFileSize.c,v 1.1 2010/07/16 14:37:56 djb Exp $ MSSL"

/*-- pre-processor statements --*/

/*-- standard C headers --*/
#include <assert.h>
#include <stdlib.h>
#include <stdio.h>
#include <unistd.h>

/*-- programmer created headers --*/
#include "kGetFileSize.h"

/*-- constant and macro headers --*/

/*-- type definitions --*/

/*-- global and external variable declarations --*/

/*-- module private (static) variable declarations --*/

/*-- functions --*/

long long int
kGetFileSize( FILE* pt_file )
{
    off_t    t_currentPos;
    off_t    t_eofPos;

    long int j_result;

    /*
     * Store the current file position and then seek to the end of the file and get
     * the new file position. The new file position is equal to the number of
     * bytes in the file. Then restore the old file position and return the size.
     * If an error occurs, return -1 and let the caller query errno if required.
     */
    t_currentPos = ftello( pt_file );

    j_result     = fseeko( pt_file, 0, SEEK_END );

    if( j_result ) {return -1; }

    t_eofPos = ftello( pt_file );

    j_result = fseeko( pt_file, t_currentPos, SEEK_SET );

    if( j_result ) {return -1; }

    return (long long int)t_eofPos;
} /* kGetFileSize */
