/*-- pre-processor statements for conditional code --*/

/* %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
+

    System: UCL Cryosat IO Library

    Sub-system: MSSL Shared

    Description:
    Find a parameter within a product

    ----------------------------------------------
    Documentation cross reference:


    ----------------------------------------------
    This file lives in ---
    ./mssl_shared

    Coding by:
    David J Brockley
    http://cryosat.mssl.ucl.ac.uk/public

    ----------------------------------------------
    Filename              :     $RCSfile: sFindParam.c,v $
    CVS Version Number    :     $Revision: 1.1 $
    Last Update           :     $Date: 2010/07/16 14:37:56 $
    What String           :     @(#)$Id: sFindParam.c,v 1.1 2010/07/16 14:37:56 djb Exp $
    Log                   :
                                $Log: sFindParam.c,v $
                                Revision 1.1  2010/07/16 14:37:56  djb
                                Port in CryoSat tools from internal branch.

                                Revision 1.2  2005/09/26 09:50:21  djb
                                Changes to documentation.

                                Revision 1.1.1.1  2005/09/23 13:51:56  djb
                                Initial import of sources to CVS.



    ----------------------------------------------
    Routines:
    sFindParam

    -----------------------------------------------------------
    This file contains the Unpublished Intellectual Property of
    University College London and All Rights Are Reserved.
        Copyright (c) University College London, 2005
    -----------------------------------------------------------
-
*/

#pragma ident "@(#)$Id: sFindParam.c,v 1.1 2010/07/16 14:37:56 djb Exp $ MSSL"

/*-- pre-processor statements --*/
#define MAX_PARAM_LEN ( 514 )

/*-- standard C headers --*/
#include <assert.h>
#include <stdlib.h>

/*-- programmer created headers --*/
#include "sFindParam.h"

/*-- constant and macro headers --*/

/*-- type definitions --*/

/*-- global and external variable declarations --*/

/*-- module private (static) variable declarations --*/

/*-- functions --*/

/* %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
+
    char* sFindParam(parameter,buffer,buffer length,return error)

    Purpose of routine:  This routine finds and returns the parameter value.

     -----------------------------------------
    Documentation cross reference

     -----------------------------------------
    Coding by:
    D J Waring  Created: 03-Feb-97	Version 1.1
    <author>	Modification: <date>	Version <version>
        <description>

    Reviewed by:
      <reviewer>	<date>	Version <version>

    Test by:
      <tester>		<date>	Version <version>
     -----------------------------------------
    Inputs:  tunables, altimeter record.

    Outputs: <none>

    Return:  <none>
     -----------------------------------------
    Pre-condition:
    buffer contains ASCII text in ESA product standard.

    Post-condition:
    Error set or parameter value returned.
     -----------------------------------------
    Calling tree: Called by :  ()
                  Calls     :
     -----------------------------------------
    Variable documentation

    Global variables used:

    Global constants used:

     -----------------------------------------
     --------------------------------------------------------------------------
-
*/

char*
sFindParam( const char* s_parameter, /* parameter to find */
            const char* s_buffer, /* buffer containing params */
            long int    j_buffer_len, /* length of buffer */
            short int*  pi_error /* error return -1=no param,0=ok */
            /*  and 1=syntax error */
            )
{
    static char s_return_value[ MAX_PARAM_LEN ]; /* return value */
    short int   i = 0;          /* loop counter */
    long int    j_buffer_off = 0;

    /* find param */
#ifdef DEBUG
    printf( "\tFindParam(%s,%li)\n", s_parameter, j_buffer_len );
#endif
    while( j_buffer_off < j_buffer_len )
    {
        /* compare letters for parameter name */
#ifdef DEBUG
        puts( "\t\tFindParam():Comparing parameter" );
#endif
        for( i = 0;
             j_buffer_off < j_buffer_len && s_buffer[ j_buffer_off ] != '\n' && s_parameter[ i ] ==
             s_buffer[ j_buffer_off ]; i++, j_buffer_off++ )
        {
            ;
        }

        /* if s_buffer[j_buffer_off]=='\n' compare next param */
#ifdef DEBUG
        puts( "\t\tFindParam():Checking line length" );
        printf( "buffer='%c'; param='%c'; off=%li >= %li\n", s_buffer[ j_buffer_off ],
                s_parameter[ i ], j_buffer_off, j_buffer_len );
#endif
        if( ( j_buffer_off >= j_buffer_len ) ||
           ( ( s_buffer[ j_buffer_off ] != '=' ) &&
        ( ( s_buffer[ j_buffer_off ] != ':' ) ||
        ( s_buffer[ j_buffer_off + 1 ] != ' ' ) ) ) || ( s_parameter[ i ] != '\0' ) )
        {
            /* find the end of the current param */
            while( j_buffer_off < j_buffer_len && s_buffer[ j_buffer_off ] != '\n' )
            {
                j_buffer_off++;
            }
            j_buffer_off++;
        }
        else
        {
            /* found, then copy param value into return buffer */
            i = 0;
            if( s_buffer[ j_buffer_off ] == ':' )
            {
                j_buffer_off++;                        /* adjust for ": " */
            }
            do
            {
                j_buffer_off++;
                s_return_value[ i ] = s_buffer[ j_buffer_off ];
                if( ++i >= MAX_PARAM_LEN )
                {
                    /* param value too long so return range error */
                    *pi_error = 2;
                    return s_return_value;
                }
            }
            while( j_buffer_off < j_buffer_len && s_buffer[ j_buffer_off ] != '\n' );
            s_return_value[ i ] = '\0';

            /* return param with error=0 (OK) */
            *pi_error = 0;
            return s_return_value;
        }
    }

    /* param not found, exit with error=-1 (param not found)*/
    *pi_error = -1;
    return s_return_value;
} /* end of sFindParam() */
