/*-- pre-processor statements for conditional code --*/

/* %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
+

    System: UCL Cryosat IO Library

    Sub-system: MSSL Shared

    Description:
    Parse and return a string

    ----------------------------------------------
    Documentation cross reference:


    ----------------------------------------------
    This file lives in ---
    ./mssl_shared

    Coding by:
    David J Brockley
    http://cryosat.mssl.ucl.ac.uk/public

    ----------------------------------------------
    Filename              :     $RCSfile: sGetString.c,v $
    CVS Version Number    :     $Revision: 1.1 $
    Last Update           :     $Date: 2010/07/16 14:37:56 $
    What String           :     @(#)$Id: sGetString.c,v 1.1 2010/07/16 14:37:56 djb Exp $
    Log                   :
                                $Log: sGetString.c,v $
                                Revision 1.1  2010/07/16 14:37:56  djb
                                Port in CryoSat tools from internal branch.

                                Revision 1.2  2005/09/26 09:50:21  djb
                                Changes to documentation.

                                Revision 1.1.1.1  2005/09/23 13:51:56  djb
                                Initial import of sources to CVS.




    ----------------------------------------------
    Routines:
    sGetString

    -----------------------------------------------------------
    This file contains the Unpublished Intellectual Property of
    University College London and All Rights Are Reserved.
        Copyright (c) University College London, 2005
    -----------------------------------------------------------
-
*/

#pragma ident "@(#)$Id: sGetString.c,v 1.1 2010/07/16 14:37:56 djb Exp $ MSSL"

/*-- pre-processor statements --*/
#define NULL ( (void*)0 )
#define PARAM_MAX_STRING_LEN ( 512 )

/*-- standard C headers --*/
#include <assert.h>
#include <stdlib.h>

/*-- programmer created headers --*/
#include "sGetString.h"
#include "sFindParam.h"

/*-- constant and macro headers --*/

/*-- type definitions --*/

/*-- global and external variable declarations --*/

/*-- module private (static) variable declarations --*/

/*-- functions --*/

/* %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
+
    char* sGetString(parameter,buffer,buffer length,return error)

    Purpose of routine:  This routine parses a string.

     -----------------------------------------
    Documentation cross reference

     -----------------------------------------
    Coding by:
    D J Waring  Created: 03-Feb-97	Version 1.1
    <author>	Modification: <date>	Version <version>
        <description>

    Reviewed by:
      <reviewer>	<date>	Version <version>

    Test by:
      <tester>		<date>	Version <version>
     -----------------------------------------
    Inputs:  parameter name, product record buffer and length.

    Outputs: error code

    Return:  string value for parameter or error.
     -----------------------------------------
    Pre-condition:
    buffer contains ASCII text in ESA product standard.

    Post-condition:
    Error set or parameter value returned.
     -----------------------------------------
    Calling tree: Called by : ()
                  Calls     :
     -----------------------------------------
    Variable documentation

    Global variables used:

    Global constants used:

     -----------------------------------------
     --------------------------------------------------------------------------
-
*/

char*
sGetString( const char* s_parameter, /* parameter to find */
            const char* s_buffer, /* buffer containing params */
            long int    j_buffer_len, /* length of buffer */
            short int*  pi_error /* error return -1=no param,0=ok */
            /*  and 1=syntax error */
            )
{
    const char* s_param_contents;   /* pointer to param string */
    char*       s_return_value = NULL; /* return value */
    short int   i;      /* counter */
    static char s_return_string[ PARAM_MAX_STRING_LEN ]; /* static to hold return value */

    /* get parameter contents */
    s_param_contents = sFindParam( s_parameter, s_buffer, j_buffer_len, pi_error );
    if( *pi_error != 0 )
    {
#ifdef DEBUG
        puts( "Param not found" );
#endif

        /* parameter doesn't exist */
        return s_return_value;
    }

    /* check format and get string */
    if( s_param_contents[ 0 ] != '"' )
    {
        /* syntax error, first char must be a '"' for a string */
#ifdef DEBUG
        puts( "Syntax: missing first \"" );
#endif
        *pi_error = 1;
        return s_return_value;
    }
    s_param_contents++;

    /* read up to next '"' */
    for( i = 0; s_param_contents[ i ] != '"' && i < PARAM_MAX_STRING_LEN; i++ )
    {
        s_return_string[ i ] = s_param_contents[ i ];
    }

    /* if i is too large, then string too big, out of range error */
    if( i == PARAM_MAX_STRING_LEN )
    {
#ifdef DEBUG
        puts( "Syntax: string too long" );
#endif
        *pi_error = 2;
        return s_return_value;
    }

    /* terminate return string */
    s_return_string[ i ] = 0;
    s_param_contents    += i + 1;

    /* do line termination test */
    if( s_param_contents[ 0 ] != '\n' )
    {
        /* syntax error, line should finish after '"' */
#ifdef DEBUG
        puts( "Syntax: no terminating line feed" );
#endif
        *pi_error = 1;
        return s_return_value;
    }
    s_return_value = s_return_string;

    /* return result with no error */
    *pi_error = 0;
    return s_return_value;
} /* end of sGetString() */
