; %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
;+
;   System:     UCL Cryosat IO Library
;   Sub-system: IDL Support
;
; ------------------------------------------------------------------------------
;
;    Filename              :     $RCSfile: cs_l1b.inc,v $
;    CVS Version Number    :     $Revision: 1.3 $
;    Last Update           :     $Date: 2014/12/01 11:30:15 $
;    What String           :     "@(#)$Id: cs_l1b.inc,v 1.3 2014/12/01 11:30:15 djb Exp $"
;    Log                   :     
;
; ------------------------------------------------------------------------------
;
;   Purpose : Supply L1B MDS format
;
; ------------------------------------------------------------------------------
;
;   Documentation cross reference
;   [PROD-FMT] Product Format Specification v4.5 20/04/2009 CS-RS-ACS-GS-5106
;
; ------------------------------------------------------------------------------
;
;   Coding by:
;   D. Brockley, 2010
;   S.G. Baker               12/04/10         Update for CS2
;
;   Reviewed by:
;   J. Gaudelli	    02/07/2014
;   
; ------------------------------------------------------------------------------
;
;   Calling tree:
;        Included by : cs_l1b_read.pro
;        Includes    : none
;
; ------------------------------------------------------------------------------
;
;   Global Variable Documentation
;   none
;
; ------------------------------------------------------------------------------
;
;   Copyright (c) University College London, 2010
;
; ------------------------------------------------------------------------------
;
;-

temp = { l1b_mph, $
         mph: BYTARR(1247) $
}
;mph block=1247 bytes

temp = { l1b_sph, $
         sph: BYTARR(2618) $          ; without DSDs
}
;sph block=2618 bytes

temp = { l1b_dsd, $                   ; single DSD
         dsd: BYTARR(280) $
}
;dsd block=280 bytes

j_timestamp_len = 12L
gj_SARIN_RW=512L
gj_SAR_RW=128L
gj_LRM_RW=128L
    
gj_Blocks=20L
gj_BeamBehaviourParams=50L

tmp=      {L1B_Time_Group, $
           Day                 : 0L,  $   ; TAI
           Sec                 : 0UL, $
           Micsec              : 0UL, $
           USO_CORR            : 0L,  $
           MODE_ID             : 0US, $
           SSC                 : 0US, $
           INST_CONFIG         : 0UL, $
           REC_COUNT           : 0UL, $
           LAT                 : 0L,  $
           LON                 : 0L,  $
           ALT                 : 0L, $
           ALT_RATE            : 0L, $
           SAT_VELOCITY        : lonarr(3), $
           REAL_BEAM           : lonarr(3), $
           BASELINE            : lonarr(3), $
           MCD                 : 0UL}

j_timegroup_len=long(j_timestamp_len+ $
                     4L+2L*2L+6L*4L+3L*3L*4L+4L)
                     
tmp=      {L1B_Measure_Group, $
           TD                   :    0LL, $    ; 2-way Window time delay 
           H_0                  :    0L, $
           COR2                 :    0L, $
           LAI                  :    0L, $
           FAI                  :    0L, $
           AGC_CH1              :    0L, $
           AGC_CH2              :    0L, $
           TR_GAIN_CH1          :    0L, $
           TR_GAIN_CH2          :    0L, $
           TX_POWER             :    0L, $
           DOPP_RC              :    0L, $
           TR_INST_RC           :    0L, $
           R_INST_RC            :    0L, $
           TR_INST_GAIN_C       :    0L, $
           R_INST_GAIN_C        :    0L, $
           INT_PHASE_C          :    0L, $
           EXT_PHASE_C          :    0L, $
           NOISE_PWR            :    0L, $
           PHASE_SLOPE_C        :    0L, $
           SPARES               :    bytarr(4)}

j_measuregroup_len_L1b= long(8L+4L*17L +8L)

tmp=      {L1B_GeoCorrections, $
           Dry_C                  : 0L, $
           Wet_C                  : 0L, $
           IB_C                   : 0L, $
           DAC_C                  : 0L, $
           Iono_GIM               : 0L, $
           Iono_mod               : 0L, $
           H_OT                   : 0L, $
           H_LPEOT                : 0L, $
           H_OLT                  : 0L, $
           H_SET                  : 0L, $
           H_GPT                  : 0L, $
           SURF_TYPE              : 0UL, $
           SPARE1                 : bytarr(4), $
           CORR_STATUS            : 0UL, $
           CORR_ERROR             : 0UL, $
           SPARE2                 : bytarr(4)}
j_geocorr_len=long(4L*13L + 12L)

tmp=      {L1B_OneHz_LRM_Wfm, $
           DAY_1Hz                   : 0L,  $   ; TAI
           SEC_1Hz                   : 0UL, $
           MICSEC_1Hz                : 0UL, $
           LAT_1Hz                   : 0L,  $
           LON_1Hz                   : 0L,  $
           ALT_1Hz                   : 0L,  $
           TD_1Hz                    : 0LL, $
           AVG_WFM                   : uintarr(gj_LRM_RW), $
           LINEAR_WFM_MULT           : 0L,  $
           POWER2_WFM_MULT           : 0L,  $
           NUM_AVG_ECHOES            : 0US, $
           FLAGS                     : 0US}
j_av_echo_lrm_len=long(j_timestamp_len+3L*4L+8L+long(gj_LRM_RW)*2L+2L*4L+2L*2L)

tmp=      {L1B_OneHz_SAR_Wfm, $
           DAY_1Hz                   : 0L,  $   ; TAI
           SEC_1Hz                   : 0UL, $
           MICSEC_1Hz                : 0UL, $
           LAT_1Hz                   : 0L,  $
           LON_1Hz                   : 0L,  $
           ALT_1Hz                   : 0L,  $
           TD_1Hz                    : 0LL, $
           AVG_WFM                   : uintarr(gj_SAR_RW), $
           LINEAR_WFM_MULTIPLIER     : 0L,  $
           POWER2_WFM_MULTIPLIER     : 0L,  $
           NUM_AVG_ECHOES            : 0US, $
           FLAGS                     : 0US}
j_av_echo_sar_len=long(j_timestamp_len+4L*3L+8L+long(gj_SAR_RW)*2L+4L+4L+2L+2L)

tmp=      {L1B_OneHz_SARIN_Wfm, $
           DAY                    : 0L,  $   ; TAI
           SEC                    : 0UL, $
           MICSEC                 : 0UL, $
           LAT                    : 0L,  $
           LON                    : 0L,  $
           ALT                    : 0L,  $
           TD                     : 0LL, $
           WFM                    : uintarr(gj_SARIN_RW), $
           LINEAR_WFM_MULTIPLIER  : 0L,  $
           POWER2_WFM_MULTIPLIER  : 0L,  $
           NUM_AVG_ECHOES         : 0US, $
           FLAGS                  : 0US}
j_av_echo_sarin_len=long(j_timestamp_len+4L*3L+8L+long(gj_SARIN_RW)*2L+4L+4L+2L+2L)

tmp=      {L1B_BeamBehaviour, $
           SD              : 0US, $
           CENTRE          : 0US, $
           AMPLITUDE       : 0US, $
           SKEW            : 0S,  $
           KURT            : 0S,  $
           SPARE           : intarr(gj_BeamBehaviourParams-5L)}

tmp=      {L1B_Wfrm_LRM, $
           WFM                        : uintarr(gj_LRM_RW), $
           LINEAR_WFM_MULTIPLIER      : 0L,  $
           POWER2_WFM_MULTIPLIER      : 0L,  $
           NUM_AVG_ECHOES             : 0US, $
           FLAGS                      : 0US }
j_lrm_wfm_l1b_len=long(long(gj_LRM_RW)*2L+4L+4L+2L+2L)

tmp=      {L1B_Wfrm_SAR, $
           WFM                        : uintarr(gj_SAR_RW), $
           LINEAR_WFM_MULTIPLIER      : 0L,  $
           POWER2_WFM_MULTIPLIER      : 0L,  $
           NUM_AVG_ECHOES             : 0US, $
           FLAGS                      : 0US, $
           BEAM                       : {L1B_BeamBehaviour}}
j_sar_wfm_l1b_len=long(long(gj_SAR_RW)*2L+4L+4L+2L+2L+long(gj_BeamBehaviourParams)*2L)

tmp=      {L1B_Wfrm_SARIN, $
           WFM                        : uintarr(gj_SARIN_RW), $
           LINEAR_WFM_MULTIPLIER      : 0L,  $
           POWER2_WFM_MULTIPLIER      : 0L,  $
           NUM_AVG_ECHOES             : 0US, $
           FLAGS                      : 0US, $
           BEAM                       : {L1B_BeamBehaviour}, $
           COHERENCE                  : intarr(gj_SARIN_RW), $
           PHASE_DIFF                 : lonarr(gj_SARIN_RW)}
j_sarin_wfm_l1b_len=long(gj_SARIN_RW*2L+4L+4L+2L+2L+gj_SARIN_RW*2L+gj_SARIN_RW*4L+gj_BeamBehaviourParams*2L)

tmp=    {   CS_l1b_lrm_mds,$
            TIME_ORBIT              : replicate( {L1B_Time_Group}, gj_Blocks ), $
            MEASUREMENTS       : replicate( {L1B_Measure_Group},       $
                                                 gj_Blocks ),               $
            GEO_CORRECTIONS   : {L1B_GeoCorrections},                     $
            AVERAGE_PL              : {L1B_OneHz_LRM_Wfm},                      $
            WAVEFORMS          : replicate( {L1B_Wfrm_LRM}, gj_Blocks) }

j_l1b_lrm_record_len = long( gj_Blocks * ( j_timegroup_len +        $
                                           j_measuregroup_len_L1b + $
                                           j_lrm_wfm_l1b_len) +     $
                             j_geocorr_len +                        $
                             j_av_echo_lrm_len )
                              

tmp=    {   CS_l1b_sar_mds,$
            TIME_ORBIT              : replicate( {L1B_Time_Group}, gj_Blocks ), $
            MEASUREMENTS       : replicate( {L1B_Measure_Group},       $
                                                 gj_Blocks ),               $
            GEO_CORRECTIONS   : {L1B_GeoCorrections},                     $
            AVERAGE_PL              : {L1B_OneHz_SAR_Wfm},                      $
            WAVEFORMS          : replicate( {L1B_Wfrm_SAR}, gj_Blocks) }

j_l1b_sar_record_len = long( gj_Blocks * ( j_timegroup_len +        $
                                           j_measuregroup_len_L1b + $
                                           j_sar_wfm_l1b_len) +     $
                             j_geocorr_len +                        $
                             j_av_echo_sar_len )
                              

tmp=    {   CS_l1b_sarin_mds,$
            TIME_ORBIT              : replicate( {L1B_Time_Group}, gj_Blocks ), $
            MEASUREMENTS       : replicate( {L1B_Measure_Group},       $
                                                 gj_Blocks ),               $
            GEO_CORRECTIONS   : {L1B_GeoCorrections},                     $
            AVERAGE_PL              : {L1B_OneHz_SARIN_Wfm},                    $
            WAVEFORMS         : replicate( {L1B_Wfrm_SARIN}, gj_Blocks) }

j_l1b_sarin_record_len = long( gj_Blocks * ( j_timegroup_len +        $
                                           j_measuregroup_len_L1b +   $
                                           j_sarin_wfm_l1b_len) +     $
                             j_geocorr_len +                          $
                             j_av_echo_sarin_len )
                              

