; %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
;+
;   System: UCL Cryosat IO Library
;   Sub-system: IDL Support
;
; ------------------------------------------------------------------------------
;
;    Filename              :     $RCSfile: cs_l2.inc,v $
;    CVS Version Number    :     $Revision: 1.2 $
;    Last Update           :     $Date: 2014/12/01 11:30:15 $
;    What String           :     "@(#)$Id: cs_l2.inc,v 1.2 2014/12/01 11:30:15 djb Exp $"
;    Log                   :     
;                                 $Log: cs_l2.inc,v $
;                                 Revision 1.2  2014/12/01 11:30:15  djb
;                                 Pre-testing for release v2.1
;
;                                 Revision 1.1  2010/07/16 14:36:03  djb
;                                 Port in CryoSat tools from internal branch.
;
;
; ------------------------------------------------------------------------------
;
;   Purpose : Supply L2 MDS format
;
; ------------------------------------------------------------------------------
;
;   Documentation cross reference
;   [C2_FMT] L2 Products Format Specification v2.5 09/06/2009 CS-RS-ACS-GS-5123 
;
; ------------------------------------------------------------------------------
;
;   Coding by:
;   S.G. Baker      Created: 29/10/02         
;   D. Brockley              13/01/04         Update for v1.1 IODD
;   D. Brockley              08/06/05         Update for v1.2 IODD
;   J. Gaudelli              01/07/14         Update for v1.8 IODD
;
;   Reviewed by:
;   D. Brockley              29/10/02
;
;   Tested by:
;   S.G. Baker               29/10/02
;
; ------------------------------------------------------------------------------
;
;   Calling tree:
;        Included by : cs_l2_read.pro
;        Includes    : none
;
; ------------------------------------------------------------------------------
;
;   Global Variable Documentation
;   none
;
; ------------------------------------------------------------------------------
;
;   Copyright (c) University College London, 2002, 2004, 2005, 2014
;
; ------------------------------------------------------------------------------
;
;-

temp = { l2_mph, $
         mph: BYTARR(1247) $
}
;mph block=1247 bytes

temp = { l2_sph, $
         sph: BYTARR(2618) $          ; without DSDs
}
;sph block=2220 bytes

temp = { l2_dsd, $                   ; single DSD
         dsd: BYTARR(280) $
}
;dsd block=280 bytes


temp = { L2_final_corrections, $
         Dry_C          :   0S,  $
         Wet_C          :   0S,  $
         IB_C           :   0S,  $
         DAC_C          :   0S,  $
         Iono_C         :   0S,  $
         SSB            :   0S,  $
         H_OT           :   0S,  $
         H_LPEOT        :   0S,  $
         H_OLT          :   0S,  $
         H_SET          :   0S,  $
         H_GPT          :   0S,  $
         Spare1         :   0S,  $
         Surf_type :   0ULL,$
         MSS_Geoid  :   0L,  $
         ODLE       :   0L,  $
         Ice_conc       :   0S,  $
         Snow_depth     :   0S,  $
         Snow_density   :   0S,  $
         Spare2         :   0S,  $
         C_status         :   0UL, $
         SWH            :   0S,  $
         Wind_speed     :   0US, $
         Spare3         :   0S,  $
         Spare4         :   0S,  $
         Spare5         :   0S,  $
         Spare6         :   0S   $
} 

temp = { L2_final_measurements, $
         D_time_mics    :   0L,    $
         Lat                  :   0L,    $
         Lon                  :   0L,    $
         Height               :   0L,    $
         SSHA_interp          :   0S,    $
         SSHA_num             :   0S,    $
         SSHA_qual            :   0S,    $
         Sig0              :   0S,    $
         Peakiness            :   0US,   $
         Freeboard            :   0S,    $
         N_avg         :   0S,    $
         Spare1               :   0S,    $
         Quality_F         :   0UL,   $
         Spare2               :   0S,    $
         Spare3               :   0S,    $
         Spare4               :   0S,    $
         Spare5               :   0S     $
}

;
; Bind all the bits of the l2_mds together into one structure
;

temp= { CS_l2_mds, $
        Day                   :   0L,    $
        Sec                   :   0L,    $
        Micsec                :   0L,    $
        Siral_mode        :   0ULL,  $
        Lat_1Hz               :   0L,    $
        Lon_1Hz               :   0L,    $
        Alt_1Hz                   :   0L,    $
        Mispointing           :   0S,    $
        N_valid             :   0S,    $
        Corr           : {L2_final_corrections}, $
        Meas          : replicate({L2_final_measurements},20)  $
}
; total bytes = 980

CS_L2_MDS_REC_SIZE = 980

;-end-
