; %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
;+
;   System:     Cryosat IPF
;   Sub-system: IDL Support
;
; ------------------------------------------------------------------------------
;
;    Filename              :     $RCSfile: cs_l2i.inc,v $
;    CVS Version Number    :     $Revision: 1.1 $
;    Last Update           :     $Date: 2010/07/16 14:36:03 $
;    What String           :     "@(#)$Id: cs_l2i.inc,v 1.1 2010/07/16 14:36:03 djb Exp $"
;    Log                   :     
;
; ------------------------------------------------------------------------------
;
;   Purpose : Supply L2I MDS format
;
; ------------------------------------------------------------------------------
;
;   Documentation cross reference
;   [C2_FMT] L2 Products Format Specification v2.5 09/06/2009 CS-RS-ACS-GS-5123 
;
; ------------------------------------------------------------------------------
;
;   Coding by:
;   S.G. Baker      Created: 29/10/02         
;   D. Brockley              13/01/04         Update for v1.1 IODD
;   D. Brockley              08/06/05         Update for v1.2 IODD
;   S.G. Baker               12/04/10         Update for CS2
;
;   Reviewed by:
;   D. Brockley              29/10/02
;
;   Tested by:
;   S.G. Baker               29/10/02
;
; ------------------------------------------------------------------------------
;
;   Calling tree:
;        Included by : cs_l2i_read.pro
;        Includes    : none
;
; ------------------------------------------------------------------------------
;
;   Global Variable Documentation
;   none
;
; ------------------------------------------------------------------------------
;
;   Copyright (c) University College London, 2010
;
; ------------------------------------------------------------------------------
;
;-

temp = { l2i_mph, $
         mph: BYTARR(1247) $
}
;mph block=1247 bytes

temp = { l2i_sph, $
         sph: BYTARR(2618) $          ; without DSDs
}
;sph block=2618 bytes

temp = { l2i_dsd, $                   ; single DSD
         dsd: BYTARR(280) $
}
;dsd block=280 bytes

temp = { L2_location, $
         Day           :   0L,  $   ; TAI
         Sec           :   0UL, $
         Micsec        :   0UL, $
         USO_Corr      :   0L,  $  ; uso correction
         Mode_ID       :   0US, $
         SSC           :   0US, $
         Inst_config   :   0UL, $
         Rec_Count     :   0UL, $
         Lat           :   0L,  $
         Lon           :   0L,  $
         Alt           :   0L,  $
         Alt_rate      :   0L,  $
         Sat_velocity  :   LONARR(3), $
         Real_beam     :   LONARR(3), $
         Baseline      :   LONARR(3), $      ; baseline vector
         L2_MCD        :   0UL  $
}
; location = 84 bytes

temp = { L2_Measurement, $
         Height           :   0L,  $
         Sig0             :   0L,  $
         SWH              :   0L,  $
         Peakiness        :   0L,  $
         Retrk_range_C    :   0L,  $
         Retrk_sig0_C     :   0L,  $
         Retrk_3          :   0L,  $
         Retrk_4          :   0L,  $
         Retrk_5          :   0L,  $
         Retrk_6          :   0L,  $
         Retrk_7          :   0L,  $
         Retrk_8          :   0L,  $
         Retrk_9          :   0L,  $
         Retrk_10         :   0L,  $
         Retrk_11         :   0L,  $
         Retrk_12         :   0L,  $
         Retrk_13         :   0L,  $
         echo_shape       :   0L,  $
         bb_param         :   INTARR(50), $
         Xtrack_ang       :   0L,  $         ; micro radians
         Coherence        :   0L,  $         ; at retrack point 1/1000
         Ocean_ht         :   0L,  $         ; mm above ellipsoid
         Freeboard        :   0L,  $         ; mm
         SHA              :   0L,  $
         SHA_interp       :   0L,  $
         interp_err       :   0US, $
         interp_cnt_fwd   :   0US, $
         interp_cnt_bkwd  :   0US, $
         interp_time_fwd  :   0US, $
         interp_time_bkwd :   0US, $
         interp_error_F   :   0US, $
         Meas_Mode        :   0UL, $
         Quality_F        :   0UL, $
         Retracker_F      :   0UL, $
         Ht_status        :   0UL, $
         Freeb_status     :   0UL, $
         n_avg            :   0US, $
         Wind_speed       :   0US, $
         spares1          :   LONARR(3) $
}
; Measurement = 244 bytes

temp = { L2_aux_measurements, $
         Ice_conc      :   0L,  $         ; % /1000
         Snow_depth    :   0L,  $
         Snow_density  :   0L,  $
         Discriminator :   0L,  $
         SARIN_disc_1  :   0L,  $
         SARIN_disc_2  :   0L,  $
         SARIN_disc_3  :   0L,  $
         SARIN_disc_4  :   0L,  $
         SARIN_disc_5  :   0L,  $
         SARIN_disc_6  :   0L,  $
         SARIN_disc_7  :   0L,  $
         SARIN_disc_8  :   0L,  $
         SARIN_disc_9  :   0L,  $
         SARIN_disc_10 :   0L,  $
         Discrim_F     :   0UL, $
         Attitude      :   0L,  $         ; micro deg
         Azimuth       :   0L,  $         ; micro deg
         Lat_sat       :   0L,  $
         Lon_sat       :   0L,  $
         Ambiguity     :   0UL, $       
         MSS_mod       :   0L,  $
         Geoid_mod     :   0L,  $
         ODLE_mod      :   0L,  $
         DEM_elev      :   0L,  $
         DEM_id        :   0L,  $
         spares2       :   LONARR(4) $
} 
; aux_measurements = 108 bytes

temp = { L2_geo_corrections, $
         Dry_C          :   0L,  $
         Wet_C          :   0L,  $
         IB_C           :   0L,  $
         DAC_C          :   0L,  $
         Iono_GIM       :   0L,  $
         Iono_mod       :   0L,  $ 
         H_OT           :   0L,  $
         H_LPEOT        :   0L,  $
         H_OLT          :   0L,  $
         H_SET          :   0L,  $
         H_GPT          :   0L,  $
         Surf_type      :   0UL, $
         Corr_status    :   0UL, $
         Corr_error     :   0UL, $
         SSB            :   0L,  $          ; Sea State Bias
         spares3        :   LONARR(2) $
} 
; geo_corrections = 64 bytes

temp = { L2_inst_corrections, $
         Dopp_rc       :   0L,  $
         TR_inst_RC    :   0L,  $
         R_inst_RC     :   0L,  $
         TR_inst_gain_C:   0L,  $
         R_inst_gain_C :   0L,  $
         Int_phase_C   :   0L,  $    
         Ext_phase_C   :   0L,  $
         Noise_pwr     :   0L,  $
		 Phase_slope_C :   0L,  $
         spares4       :   LONARR(2) $
} 
; inst_corrections = 44 bytes

;
; Bind all the bits of the l2_mds together into one structure
;

temp= { CS_l2i_mds, $
        location  : {L2_location}, $
        surf      : {L2_Measurement}, $
        aux       : {L2_aux_measurements}, $
        geo       : {L2_geo_corrections}, $
        inst      : {L2_inst_corrections} $
}
; total bytes = 544

CS_L2I_MDS_REC_SIZE = 556

;-end-
