; %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
;+
;   System:     UCL Cryosat IO Library
;   Sub-system: IDL Support
;
; ------------------------------------------------------------------------------
;
;    Filename              :     $RCSfile: decode_error.pro,v $
;    CVS Version Number    :     $Revision: 1.1 $
;    Last Update           :     $Date: 2010/07/16 14:36:03 $
;    What String           :     "@(#)$Id: decode_error.pro,v 1.1 2010/07/16 14:36:03 djb Exp $"
;    Log                   :     
;                                 $Log: decode_error.pro,v $
;                                 Revision 1.1  2010/07/16 14:36:03  djb
;                                 Port in CryoSat tools from internal branch.
;
;
; ------------------------------------------------------------------------------
;
;   Purpose : Handles errors generated within an IDL module
;
; ------------------------------------------------------------------------------
;
;   Documentation cross reference
;   none
;
; ------------------------------------------------------------------------------
;
;   Coding by:
;   S. Baker and D. Brockley, 2005
;
; ------------------------------------------------------------------------------
;   Inputs
;    none
;
;   Keywords
;    i_error_number :  Error Number	(mandatory)
;
;   Outputs
;    none
; ------------------------------------------------------------------------------
;   Calling tree : 
;        Included by : none
;        Includes    : none
;          Called by : n/a (library routine)
;	   Calls	 : report_error
; ------------------------------------------------------------------------------
;   Global Variable Documentation
;     none
; ------------------------------------------------------------------------------
;
;   Copyright (c) University College London, 2005
;
; ------------------------------------------------------------------------------
;
;-

PRO decode_error, ERROR_NUMBER=i_error_number

; -- local variable declarations ----------------------------------------------
    s_error_string =	string('')		; error string

; -- if ERROR_NUMBER keyword is not set, set to info string -------------------
	if (N_ELEMENTS(i_error_number) eq 0) then $
            i_error_number='Module called incorrectly'

; -- assign error string depending on error number ---------------------------
    case i_error_number of
      0 : s_error_string = 'DIAGNOSTIC:  NO ERROR HAS OCCURED'

      10 : s_error_string = 'Error: Records to be read <= 0'
      11 : s_error_string = 'Error: Records to be skipped < 0'
      12 : s_error_string = $
          'File does not conform to the PSD : Invalid file size'
      13 : s_error_string = $
          'File does not conform to the PSD : Invalid number of blocks'
      14 : s_error_string = $
          'File does not conform to the PSD : Invalid block name'
      15 : s_error_string = 'Requested block not present in product'
      16 : s_error_string = 'Requested parameter not present in block'
      17 : s_error_string = 'Requested block name is invalid'
      18 : s_error_string = 'Error allocating parameter storage'
      19 : s_error_string = 'Invalid record size'

      20 : s_error_string = 'Invalid flag type supplied to bitplot.pro'

      21 : s_error_string = 'File does not start with a valid PDS MPH'
      22 : s_error_string = 'File does not have a valid PDS SPH'
      23 : s_error_string = 'Can not find TOT_SIZE field'
      24 : s_error_string = 'Can not find SPH_SIZE field'
      25 : s_error_string = 'Can not find NUM_DSD field'
      26 : s_error_string = 'Can not find DSD_SIZE field'
      27 : s_error_string = 'Can not find NUM_DATA_SETS field'
      28 : s_error_string = 'Can not find correct DSD field'
      29 : s_error_string = 'File size error'

      30 : s_error_string = $
	  'Parameters supplied to plotgeo.pro have invalid dimensions'

    else : $
      s_error_string = 'DIAGNOSTIC:  INVALID ERROR NUMBER :'+$
                       string(i_error_number)
    endcase

; -- report error -------------------------------------------------------------
    report_error,s_error_string

end		;decode_error
